<?php
/**
 * This file has been @generated by a phing task from CLDR version 40.0.0.
 * See [README.md](README.md#generating-data) for more information.
 *
 * @internal Please do not require this file directly.
 * It may change location/format between versions
 *
 * Do not modify this file directly!
 */

return array (
  'BR' => 'ᱵᱨᱟᱡᱤᱞ',
  'CN' => 'ᱪᱤᱱ',
  'DE' => 'ᱡᱟᱨᱢᱟᱱᱤ',
  'FR' => 'ᱯᱷᱨᱟᱱᱥ',
  'GB' => 'ᱭᱩᱱᱤᱭᱴᱮᱰ ᱠᱤᱝᱰᱚᱢ',
  'IN' => 'ᱤᱱᱰᱤᱭᱟ',
  'IT' => 'ᱤᱴᱞᱤ',
  'JP' => 'ᱡᱟᱯᱟᱱ',
  'RU' => 'ᱨᱩᱥ',
  'US' => 'ᱭᱩᱱᱟᱭᱴᱮᱰ ᱮᱥᱴᱮᱴ',
);
