OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Naziv je predug",
    "The given web address is too long" : "Navedena adresa web-mjesta je preduga",
    "The given web address is not a valid URL" : "Navedena adresa web-mjesta nije važeći URL",
    "The given legal notice address is too long" : "Navedena adresa pravne obavijesti je preduga",
    "The given legal notice address is not a valid URL" : "Navedena adresa pravne obavijesti nije važeći URL",
    "The given privacy policy address is too long" : "Navedena adresa pravila o privatnosti je preduga",
    "The given privacy policy address is not a valid URL" : "Navedena adresa pravila o privatnosti nije važeći URL",
    "The given slogan is too long" : "Navedeni slogan je predug",
    "The given color is invalid" : "Navedena boja nije važeća",
    "Saved" : "Spremljeno",
    "The file was uploaded" : "Datoteka je otpremljena",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
    "No file was uploaded" : "Nije otpremljena nijedna datoteka",
    "Missing a temporary folder" : "Nedostaje privremena mapa",
    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
    "No file uploaded" : "Nije otpremljena nijedna datoteka",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Već koristite prilagođenu temu. Te postavke mogu biti zamijenjene postavkama aplikacije za upravljanje temama.",
    "Theming" : "Upravljanje temama",
    "Dark theme" : "Tamna tema",
    "Enable dark theme" : "Omogući tamnu temu",
    "Dyslexia font" : "Font za osobe s disleksijom",
    "Enable dyslexia font" : "Omogući font za osobe s disleksijom",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je besplatan font/izgled slova posebno osmišljen za ublažavanje nekih uobičajenih pogrešaka pri čitanju uzrokovanih disleksijom.",
    "High contrast mode" : "Način jakog kontrasta",
    "Enable high contrast mode" : "Omogući način jakog kontrasta",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Način jakog kontrasta olakšava navigaciju. Smanjuje vizualnu kvalitetu, ali povećava jasnoću prikaza.",
    "Legal notice" : "Pravna obavijest",
    "Privacy policy" : "Pravila o privatnosti",
    "Adjust the Nextcloud theme" : "Prilagodi temu Nextclouda",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Upravljanje temama omogućuje jednostavno prilagođavanje izgleda vaše instance i podržanih klijenata. To će biti vidljivo svim korisnicima.",
    "Advanced options" : "Napredne opcije",
    "Name" : "Naziv",
    "Web link" : "Web poveznica",
    "a safe home for all your data" : "siguran dom za sve vaše podatke",
    "Slogan" : "Slogan",
    "Color" : "Boja",
    "Logo" : "Logotip",
    "Upload new logo" : "Otpremi novi logotip",
    "Legal notice link" : "Poveznica na pravnu obavijest",
    "Privacy policy link" : "Poveznica na pravila o privatnosti",
    "Header logo" : "Logotip zaglavlja",
    "Upload new header logo" : "Otpremi novi logotip zaglavlja",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Otpremi novi favicon",
    "User settings" : "Korisničke postavke",
    "Background" : "Pozadina",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Nama je vrlo važno osigurati univerzalan pristup. Pratimo sve internetske i mrežne standarde i provjeravamo je li sustav upotrebljiv bez miša i pomoćnog softvera, kao što je čitač zaslona. Naš je cilj postići sukladnost sa {guidelines}Smjernicama pristupačnosti web-sadržaja{linkend} 2.1 na razini AA s temom jakog kontrasta na razini AAA.",
    "Move up" : "Premjesti gore",
    "Move down" : "Premjesti dolje",
    "Change color" : "Promijeni boju",
    "Reset to default" : "Vrati na zadanu postavku",
    "Upload" : "Otpremi",
    "Remove background image" : "Ukloni pozadinsku sliku",
    "Loading preview…" : "Učitavanje pretpregleda...",
    "Admin" : "Administrator",
    "Name cannot be empty" : "Naziv ne može biti prazan",
    "Pick from Files" : "Odaberi iz datoteka",
    "Custom color" : "Prilagođena boja",
    "Plain background" : "Obična pozadina",
    "Insert from {productName}" : "Umetni iz {productName}",
    "Open documentation" : "Otvori dokumentaciju",
    "https://…" : "https://…",
    "Upload new login background" : "Otpremi novu pozadinu za prijavu",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ugradite proširenje za PHP pod nazivom Imagemagick s podrškom za SVG slike kako biste automatski generirali favicone na temelju otpremljenog logotipa i boje."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
