OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Versións",
    "This application automatically maintains older versions of files that are changed." : "Esta aplicación mantén automaticamente versións antigas dos ficheiros que cambian.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the user does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the user's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Esta aplicación mantén automaticamente versións antigas dos ficheiros que cambian. Ao activarse, crease un cartafol agochado de versións que se emprega para almacenar versións antigas de ficheiros. Un usuario pode reverter cara a unha versión anterior a través da interface web en calquera momento, co ficheiro substituído converténdose nunha versión. A aplicación xestiona automaticamente o cartafol de versións para asegurarse de que o usuario non queda sen espazo por mor das versións.\n\t\tAdemais da caducidade de versións, a aplicación de versións asegurase de non empregar nunca máis do 50% do espazo libre actualmente dispoñíbel para un usuario. Se as versións almacenadas exceden este límite, a aplicación eliminará as versións máis antigas ata acadar este límite. Hai máis información dispoñíbel na documentación de Versións.",
    "Name this version" : "Nomear esta versión",
    "Edit version name" : "Editar o nome da versión",
    "Compare to current version" : "Comparar coa versión actual",
    "Restore version" : "Restaurar a versión",
    "Download version" : "Descargar a versión",
    "Delete version" : "Eliminar a versión",
    "Version name" : "Nome da versión",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "As versións con nome mantéñense e exclúense das limpezas automáticas cando a súa cota de almacenamento estea completa.",
    "Remove version name" : "Retirar o nome da versión",
    "Save version name" : "Gardar o nome da versión",
    "Current version" : "Versión actual",
    "Initial version" : "Versión inicial",
    "Initial version restored" : "A versión inicial foi restaurada",
    "Version restored" : "A versión foi restaurada",
    "Could not restore version" : "Non foi posíbel restaurar a versión",
    "Could not set version name" : "Non foi posíbel estabelecer o nome da versión",
    "Could not delete version" : "Non foi posíbel eliminar a versión",
    "${version.label} restored" : "${version.label} foi restaurada",
    "Failed to revert {file} to revision {timestamp}." : "Non foi posíbel reverter {file} á revisión {timestamp}.",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Restore" : "Restaurar",
    "No other versions available" : "Non hai outras versións dispoñíbeis"
},
"nplurals=2; plural=(n != 1);");
