OC.L10N.register(
    "twofactor_totp",
    {
    "Authenticate with a TOTP app" : "Autentiser med to-faktor program",
    "Enable TOTP" : "Aktivere to-faktor pålogging",
    "Authentication code" : "Autentifikasjons kode",
    "Verify" : "Stadfest"
},
"nplurals=2; plural=(n != 1);");
