OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Nastavitve preprečevanja nasilnega vdora",
    "Whitelist IPs" : "Beli seznam naslovov IP",
    "Brute-force IP whitelist" : "Beli seznam naslovov IP za preprečevanje nasilnega vdora",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Za dodajanje na beli seznam je treba posamezen naslov ali obseg naslovov IP vpisati v spodnje polje. Vedite, da lahko katerikoli naslov IP s seznama opravlja overitve brez vsakršnega zadrževanja, zato je iz varnostnih razlogov priporočljivo, da je na belem seznamu čim manj gostiteljev ali celo nobenega.",
    "Add new whitelist" : "Dodaj nov beli seznam",
    "Add" : "Dodaj",
    "Delete" : "Izbriši"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
