OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Personvern",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Personvernsenteret viser deg hvor dataene dine er lagret og hvem som har tilgang til dem, enten fordi du har delt med dem eller fordi de er administratorer.",
    "Remove external {propertyName} admin" : "Fjern ekstern {propertyName}-admin",
    "Add external admin" : "Legg til ekstern admin",
    "Name of external admin" : "Navn til ekstern admin",
    "Adapt encryption" : "Tilpass kryptering",
    "This server is using full-disk-encryption." : "Denne serveren bruker full-disk kryptering.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Hjemmelagringen din er kryptert med {linkopen}server-side-kryptering ↗{linkclose} med en hovednøkkel. Det betyr at administratorer kan få tilgang til filene dine, men ikke lese innholdet.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Filene dine på eksterne lagringer kan krypteres med {linkopen}server-side-kryptering ↗{linkclose} med en hovednøkkel basert på deres konfigurasjon.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Hjemmelagringen din er kryptert med {linkopen}server-side-kryptering ↗{linkclose} med en individuell brukernøkkel. Det betyr at administratorer kan få tilgang til filene dine, men ikke lese innholdet.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Filene dine på eksterne lagringsenheter kan krypteres ved hjelp av {linkopen}server-side-kryptering ↗{linkclose} med en individuell nøkkel basert på deres konfigurasjon.",
    "Additionally, this server is protected with full-disk-encryption." : "I tillegg er denne serveren beskyttet med full-disk-kryptering.",
    "This server is protected with full-disk-encryption." : "Filene dine er beskyttet med full-disk kryptering.",
    "Your files are not protected by encryption." : "Filene dine er ikke beskyttet med kryptering.",
    "Your data is located in:" : "Dine data er plassert i:",
    "The admin has not selected the location of the server yet." : "Administratoren har ikke valgt plasseringen til serveren ennå.",
    "Change data location" : "Endre dataplassering",
    "Please select a region" : "Vennligst velg en region",
    "You don't have any shares with individual users." : "Du har ingen delinger med individuelle brukere.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "De forente arabiske emirater",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua og Barbuda",
    "Anguilla" : "Angola",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikansk Samoa",
    "Austria" : "Østerike",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Aserbajdsjan",
    "Bosnia and Herzegovina" : "Bosnia og Hersegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint-Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius og Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvetøya",
    "Botswana" : "Botswana",
    "Belarus" : "Hviterusland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosøyene",
    "Democratic Republic of the Congo" : "Den demokratiske republikken Kongo",
    "Central African Republic" : "Den sentralafrikanske republikk",
    "Congo" : "Kongo",
    "Switzerland" : "Sveits",
    "Cote d'Ivoire" : "Elfenbenskysten",
    "Cook Islands" : "Cookøyene",
    "Chile" : "Chile",
    "Cameroon" : "Kameron",
    "China" : "Kina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kapp Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmasøya",
    "Cyprus" : "Kypros",
    "Czech" : "Tsjekkia",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominican Republic" : "Den dominikanske republikk",
    "Algeria" : "Algeri",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypt",
    "West Sahara" : "Vest-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandsøyene",
    "Micronesia" : "Mikronesia",
    "Faroe Islands" : "Færøyene",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom" : "Storbritannia",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Fransk Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grønland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatorial-Guinea",
    "Greece" : "Hellas",
    "South Georgia and the South Sandwich Islands" : "Sør-Georgia og Sør-Sandwichøyene",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard- og McDonaldøyene",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Det britiske territoriet i Indiahavet",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgisistan",
    "Cambodia" : "Kambodia",
    "Kiribati" : "Kiribati",
    "Comores" : "Komorene",
    "Saint Kitts and Nevis" : "Saint Kitts og Nevis",
    "North Korea" : "Nord-Korea",
    "South Korea" : "Sør-Korea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Caymanøyene",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshalløyene",
    "Macedonia" : "Makedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Nord-Marianene",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldivene",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Ny-Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkøya",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransk Polynesia",
    "Papua New Guinea" : "Papua Ny-Guinea",
    "Philippines" : "Filippinene",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre og Miquelon",
    "Pitcairn" : "Pitcairnøyene",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomonøyene",
    "Seychelles" : "Seychellene",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension og Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard og Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sør-Sudan",
    "Sao Tome and Principe" : "Sao Tome og Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syria",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Turks- og Caicosøyene",
    "Chad" : "Tsjad",
    "Fr. S. Antarctic Lands" : "De franske sørterritorier",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadsjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Tyrkia",
    "Trinidad and Tobago" : "Trinidad og Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "USAs ytre småøyer",
    "United States" : "USA (De Forente Stater)",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Holy See" : "Den hellige stol",
    "Saint Vincent and the Grenadines" : "Saint Vincent og Grenadinene",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "De britiske Jomfruøyer",
    "Virgin Islands (U.S.)" : "De amerikanske Jomfruøyer",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis- og Futunaøyene",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sør-Afrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your %s account" : "%s-kontoen din",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Din informasjon representerer hvem du er, og kan enkelt misbrukes. Vi hos Nextcloud mener at du har retten til å velge hva som skjer med din informasjon. Nextcloud beskytter dine rettigheter som er definert i Brukerdata-Manifestoet!",
    "User Data Manifesto 2.0" : "Brukerdatamanifestet 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definere grunnleggende rettigheter for mennesker til å kontrollere sine egne data i internettalderen",
    "Control" : "Kontroll",
    "over user data access" : "over brukerdata tilgang",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Data som er eksplisitt og villig lastet opp av en bruker, bør være under brukerens endelige kontroll. Brukere bør kunne bestemme hvem de skal gi direkte tilgang til dataene deres og med hvilke tillatelser og lisenser slik tilgang skal gis.",
    "Knowledge" : "Kunnskap",
    "of how the data is stored" : "om hvordan informasjonen er lagret",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Når dataene lastes opp til en spesifikk tjenesteleverandør, bør brukere informeres om hvor den spesifikke tjenesteleverandøren lagrer dataene, hvor lenge, i hvilken jurisdiksjon den spesifikke tjenesteleverandøren opererer, og hvilke lover som gjelder.",
    "Freedom" : "Frihet",
    "to choose a platform" : "å velge en plattform",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Brukere skal alltid kunne ta ut dataene sine fra tjenesten når som helst uten å oppleve å være låst til en leverandør. Åpne standarder for formater og protokoller er nødvendig for å garantere dette.",
    "Learn more ↗" : "Lær mer ↗",
    "Where is your data?" : "Hvor er dataene dine?",
    "Who has access to your data?" : "Hvem har tilgang til din informasjon?",
    "Administrators" : "Administratorer",
    "People you shared with" : "Folk du delte med",
    "Privacy policy" : "Personvern politikk",
    "Read the privacy policy." : "Les personvernsærkleringen.",
    "Encryption" : "Kryptering",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Hjemmelagringen din er kryptert med {linkopen}server-side-kryptering ↗{linkclose} med en hovednøkkel.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Hjemmelagringen din er kryptert med {linkopen}server-side-kryptering ↗{linkclose} med en individuell brukernøkkel."
},
"nplurals=2; plural=(n != 1);");
