OC.L10N.register(
    "text",
    {
    "New text file" : "Нови текстуални фајл",
    "Create new text file" : "Креирај нови текст фајл",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Фајл за отпремање премашује upload_max_filesize директиву у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE наведену у ХТМЛ обрасцу",
    "The file was only partially uploaded" : "Фајл је парцијално отпремљен",
    "No file was uploaded" : "Није отпремљен фајл",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да упишем фајл на диск",
    "A PHP extension stopped the file upload" : "ПХП екстензија је зауставила отпремање фајла",
    "No file uploaded or file size exceeds maximum of %s" : "Ниједан фајл није отпремљен или величина фајла премашује максимум од %s",
    "Nextcloud Text" : "Некстклауд Текст",
    "text document" : "текстуални документ",
    "{user} has mentioned you in the text document {node}" : "{user} вас је поменуо у текст документу {node}",
    "This file cannot be displayed as download is disabled by the share" : "Овај фајл не може да се прикаже јер дељење спречава преузимање",
    "Readme" : "Прочитај ме",
    "Text" : "Текст",
    "📝 Collaborative document editing" : "📝 Заједничко уређивање докумената",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 Заједничко уређивање докумената!**\n\n- **📝 Фокус на писању:** Нема ометања, само форматираер које вам треба.\n- **🙋 Радите заједно:** Делите и радите заједно са пријатељима и колегама, без обзира да ли имају Некстклауд или не!\n- **💾 Отворени формат:** Фајлови се чувају као [Markdown](https://en.wikipedia.org/wiki/Markdown), тако да их можете мењати из било које друге апликације.\n- **✊ Јаки темељи:** Користимо [🐈 tiptap](https://tiptap.scrumpy.io) који се базира на [🦉 ProseMirror-у](https://prosemirror.net) – пуно им хвала!",
    "Nextcloud Assistant" : "Nextcloud Асистент",
    "Translate" : "Превођење",
    "Show assistant results" : "Прикажи резултате асистента",
    "Insert result" : "Уметни резултат",
    "Show result" : "Прикажи резултат",
    "Delete task" : "Обриши задатак",
    "Nextcloud Assistant result copied" : "Копиран је резултат Nextcloud Асистента",
    "Could not copy result to clipboard" : "Резултат није могао да се копира у клипборд",
    "Use current version" : "Користи тренутну верзију",
    "Use the saved version" : "Користи сачувану верзију",
    "Failed to load file" : "Није успело учитавање фајла",
    "Document idle for {timeout} minutes, click to continue editing" : "Документ није промењен {timeout} минута, кликните да наставите уређивање",
    "Reconnect" : "Поново повежи",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Документ је измењен ван уређивача. Измене се не могу применити.",
    "File could not be loaded. Please check your internet connection." : "Фајл не може да се учита. Проверите интернет конекцију.",
    "This file is opened read-only as it is currently locked by {user}." : "Овај фајл је отворен у режиму само-за-читање, и тренутно га је закључао {user}.",
    "Close outline view" : "Затвори контурни приказ",
    "Outline" : "Контура",
    "Enter your name so other people can see who is editing" : "Унесите своје име тако да остали могу видети ко уређује",
    "Edit guest name" : "Измени име госта",
    "Guest" : "Гост",
    "Save guest name" : "Сачувај име госта",
    "Insert an attachment" : "Уметни прилог",
    "guest" : "гост",
    "Show author colors" : "Прикажи боје аутора",
    "Author colors are only shown until everyone has closed the document." : "Боје аутора се приказују све док сви не затворе документ.",
    "Active people" : "Активне особе",
    "Save document" : "Сачувај документ",
    "Last saved" : "Последње сачувано",
    "Offline" : "Ван мреже",
    "Offline, changes will be saved when online" : "Ван мреже, измене ће се сачувате када будете на мрежи",
    "Saving …" : "Чувам…",
    "Saved" : "Сачувано",
    "Last saved {lastSave}" : "Последње сачувано {lastSave}",
    "Unsaved changes" : "Несачуване измене",
    "Formatting help" : "Помоћ око форматирања",
    "Speed up your writing with simple shortcuts." : "Убрзајте своје уређивање простим пречицама.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "Једноставно куцајте Markdown синтаксу или користите пречице на тастатури приказане испод.",
    "Just type the Markdown syntax from below." : "Једноставно куцајте Markdown синтаксу приказану испод.",
    "Style" : "Стил",
    "Syntax" : "Синтакса",
    "Keyboard shortcuts" : "Пречице на тастатури",
    "New paragraph" : "Нови пасус",
    "Enter" : "Ентер",
    "Hard line break" : "Тврди прелом реда",
    "followed by" : "следи",
    "Backspace" : "Брисање улево",
    "Shift" : "Помери",
    "Bold" : "Подебљано",
    "Bold text" : "Подебљани текст",
    "Ctrl" : "Ctrl",
    "Italic" : "Курзив",
    "Italicized text" : "Курзивни текст",
    "Strikethrough" : "Прецртано",
    "Mistaken text" : "Текст са грешком",
    "Underline" : "Подвучено",
    "Underlined text" : "Подвучени текст",
    "Heading 1" : "Наслов 1",
    "Heading level 1" : "Наслов нивоа 1",
    "Heading 6" : "Наслов 6",
    "Heading level 6" : "Наслов нивоа 6",
    "Unordered list" : "Неуређена листа",
    "An item" : "Ставка",
    "Ordered list" : "Уређена листа",
    "First item" : "Прва ставка",
    "Checklist" : "Листа потврда",
    "To-Do item" : "Ставка обавезе",
    "Blockquote" : "Издвојени цитат",
    "Quoted text" : "Цитирани текст",
    "Code block" : "Блок са изворним кôдом",
    "Some code" : "Неки кôд",
    "Upload from computer" : "Отпреми са компјутера",
    "Insert from Files" : "Уметни из Фајлова",
    "Remove link" : "Уклони линк",
    "Link to file or folder" : "Линк на фајл или фолдер",
    "Link to website" : "Линк на веб сајт",
    "Update link" : "Ажурирај везу",
    "Open the Smart Picker" : "Отвори Паметни бирач",
    "Select file or folder to link to" : "Изаберите фајл или фордер на који показује линк",
    "_%n word_::_%n words_" : ["%n реч","%n речи","%n речи"],
    "_%n char_::_%n chars_" : ["%n карактер","%n карактера","%n карактера"],
    "Editor actions" : "Акције едитора",
    "Formatting menu bar" : "Линија менија форматирања",
    "Remaining actions" : "Преостале акције",
    "To translate individual parts of the text, select it before using the translate function." : "Ако желите да преведете одређене делове текста, изаберите их пре него што употребите функцију превода.",
    "Translate from" : "Преведи са",
    "Select language" : "Одаберите језик",
    "to" : "за",
    "Replace" : "Замени",
    "Insert" : "Уметни",
    "Detect language" : "Откриј језик",
    "Translate from {language}" : "Преведи са {language}",
    "Translate to {language}" : "Преведи на {language}",
    "Translation failed" : "Превођење није успело",
    "No emoji found" : "Није пронађен емођи",
    "No command found" : "Није пронађена команда",
    "No user found" : "Није пронађен корисник",
    "No suggestion found" : "Није пронађен предлог",
    "Code block options" : "Опције блока кода",
    "Code block language" : "Језик блока кода",
    "e.g. php, javascript, json…" : "нпр. php, javascript, json…",
    "Source code" : "Изворни кôд",
    "Diagram" : "Дијаграм",
    "Both" : "Оба",
    "Mermaid documentation" : "Mermaid документација",
    "Link to this section" : "Линк на овај одељак",
    "Delete this attachment" : "Обриши овај прилог",
    "Delete this image" : "Обриши ову слику",
    "Failed to load" : "Учитавање није успело",
    "Unsupported image type" : "Неподржани тип слике",
    "Add row before" : "Додај ред испред",
    "Add row after" : "Додај ред након",
    "Delete this row" : "Обриши овај ред",
    "Left align column" : "Лево поравната колона",
    "Center align column" : "Колона поравната по средини",
    "Right align column" : "Десно поравната колона",
    "Add column before" : "Додај колону испред",
    "Add column after" : "Додај колону иза",
    "Delete this column" : "Обриши ову колону",
    "Delete this table" : "Обриши ову табелу",
    "Show folder description" : "Прикажи опис фолдера",
    "Hide outline" : "Сакриј контуру",
    "Show outline" : "Прикажи контуру",
    "Undo" : "Поништи",
    "Redo" : "Понови",
    "Headings" : "Наслови",
    "Heading 2" : "Наслов 2",
    "Heading 3" : "Наслов 3",
    "Heading 4" : "Наслов 4",
    "Heading 5" : "Наслов 5",
    "To-Do list" : "Листа обавеза",
    "Insert link" : "Уметни линк",
    "Callouts" : "Балончићи",
    "Info" : "Инфо",
    "Success" : "Успешно",
    "Warning" : "Упозорење",
    "Danger" : "Опасност",
    "Table" : "Табела",
    "Insert emoji" : "Уметни емођи",
    "Insert attachment" : "Убаци прилог",
    "Command" : "Команда",
    "Control" : "Контрола",
    "Option" : "Опција",
    "Formatting" : "Форматирање",
    "Smart picker" : "Паметни бирач",
    "Add notes, lists or links …" : "Додајте белешке, спискове или везе…",
    "Edit" : "Измени",
    "Add description" : "Додај опис",
    "\"{name}\" already exist!" : "„{name}” већ постоји!",
    "Created \"{name}\"" : "„{name}” је креирано",
    "Front matter" : "Уводни део",
    "Document save status" : "Статус чувања документа",
    "Update Link" : "Ажурирај линк",
    "Add Link" : "дај линк",
    "Link file" : "Увежи фајл",
    "Remove Link" : "Уклони линк",
    "Select file to link to" : "Одаберите фајл на који да направите везу",
    "Show rich workspaces" : "Прикажи обогаћена радна места",
    "Source language" : "Изворни језик",
    "Target language" : "Циљни језик",
    "e.g. php, javascript, json, ..." : "нпр. php, javascript, json, ..."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
