OC.L10N.register(
    "files_versions",
    {
    "Versions" : "الإصدارات",
    "This application automatically maintains older versions of files that are changed." : "هذا التطبيق يقوم بحفظ النسخ الأقدم من الملفات التي يتم تعديلها.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the user does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the user's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "هذا التطبيق يقوم بحفظ النسخ الأقدم من الملفات التي يتم تعديلها. عند تفعيله، يتم توفير مُجلد مخفي في دليل المستخدم لحفظ النسخ الأقدم للملفات. و يمكن للمستخدم العودة لأي نسخة قديمة من الملف من خلال الشاشة في أي لحظة. و حينها يتم نقل النسخة الأقدم المحفوظة لتصبح هي النسخة العامة و بالمقابل يتم نسخ النسخة العاملة لتصبح ضمن النُّسخ الأقدم. \nلا يسمح النظام بأن تتجاوز مساحة تخزين النُّسخ الأقدم 50% من حصة المستخدم المُتاحة. عند تضاؤل مساحة التخزين المُتاحة من حصة المستخدم، يقوم النظام بحذف النُّسخ الأقدم فالأقدم بحيث لا تقل حصة لا تشغل النُّسخ الأقدم أكثر من 50% من حصة المستخدم في جميع الأحوال. للمزيد؛ أنظر توثيق النُّسخ Version documenation.",
    "Name this version" : "أعط اسماً لهذه النسخة",
    "Edit version name" : "عدّل اسم النسخة",
    "Compare to current version" : "قارِن مع النسخة الحاليّة",
    "Restore version" : "استعادة النسخة",
    "Download version" : "تنزيل النسخة",
    "Delete version" : "حذف النسخة",
    "Version name" : "اسم النسخة",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "النُّسخ المُسمّاة محفوظة و مُستثناة من التنظيف التلقائي عند تضاؤل المٌتاح من الحصة التخزينية.",
    "Remove version name" : "إلغ اسم النسخة",
    "Save version name" : "إحفظ اسم النسخة",
    "Current version" : "الإصدار الحالي",
    "Initial version" : "النسخة الأساسية",
    "Initial version restored" : "استعادة النسخة الأساسية",
    "Version restored" : "تمّت استعادة النسخة",
    "Could not restore version" : "لم يُمكن استعادة النسخة",
    "Could not set version name" : "لم يُمكن تعيين اسم للنسخة",
    "Could not delete version" : "لم يُمكن حذف النسخة",
    "${version.label} restored" : "${version.label} تمّت استعادتها",
    "Failed to revert {file} to revision {timestamp}." : "فشل في استعادة {ملف} لنتقيح {الطابع الزمني}",
    "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%n بايت"],
    "Restore" : "استعادة ",
    "No other versions available" : "لا تتوفر هناك نُسخ أخرى"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
