OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "To-dos" : "Da fare",
    "Personal" : "Personale",
    "{actor} created calendar {calendar}" : "{actor} ha creato il calendario {calendar}",
    "You created calendar {calendar}" : "Hai creato il calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha eliminato il calendario {calendar}",
    "You deleted calendar {calendar}" : "Hai eliminato il calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha aggiornato il calendario {calendar}",
    "You updated calendar {calendar}" : "Hai aggiornato il calendario {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} ha ripristinato il calendario {calendar}",
    "You restored calendar {calendar}" : "Hai ripristinato il calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Hai condiviso il calendario {calendar} come collegamento pubblico",
    "You removed public link for calendar {calendar}" : "Hai rimosso il collegamento pubblico per il calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha condiviso il calendario {calendar} con te",
    "You shared calendar {calendar} with {user}" : "Hai condiviso il calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha aggiornato il calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha rimosso la condivisione del calendario {calendar} con te",
    "You unshared calendar {calendar} from {user}" : "Hai rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ha rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ha rimosso la condivisione del calendario {calendar} con se stesso",
    "You shared calendar {calendar} with group {group}" : "Hai condiviso il calendario {calendar} con il gruppo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha condiviso il calendario {calendar} con il gruppo {group}",
    "You unshared calendar {calendar} from group {group}" : "Hai rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ha rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "Untitled event" : "Evento senza titolo",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creato l'evento {event} nel calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Hai creato l'evento {event} nel calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha eliminato l'evento {event} dal calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Hai ha eliminato l'evento {event} dal calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ha aggiornato l'evento {event} nel calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Hai aggiornato l'evento {event} nel calendario {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} ha spostato l'evento {event} dal calendario {sourceCalendar} al calendario {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Hai spostato l'evento {event} dal calendario {sourceCalendar} al calendario {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} ha ripristinato l'evento {event} del calendario {calendar}",
    "You restored event {event} of calendar {calendar}" : "Hai ripristinato l'evento {event} del calendario {calendar}",
    "Busy" : "Occupato",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} ha aggiunto la cosa da fare {todo} nella lista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Hai aggiunto la cosa da fare {todo} nella lista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} ha eliminato la cosa da fare {todo} dalla lista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Hai eliminato la cosa da fare {todo} dalla lista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} ha aggiornato la cosa da fare {todo} nella lista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Hai aggiornato la cosa da fare {todo} nella lista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} ha risolto la cosa da fare {todo} nella lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Hai risolto la cosa da fare {todo} nella lista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} ha riaperto la cosa da fare {todo} nella lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Hai riaperto la cosa da fare {todo} nella lista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} ha spostato la cosa da fare {todo} dalla lista {sourceCalendar} alla lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Hai spostato la cosa da fare {todo} dalla lista {sourceCalendar} alla lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendario, contatti e attività",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> è stato modificato",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario è stato modificato",
    "A calendar <strong>to-do</strong> was modified" : "Una <strong>cosa da fare</strong> del calendario è stata modificata",
    "Contact birthdays" : "Date di nascita dei contatti",
    "Death of %s" : "Morte di %s",
    "Untitled calendar" : "Calendario senza titolo",
    "Calendar:" : "Calendario:",
    "Date:" : "Data:",
    "Where:" : "Dove:",
    "Description:" : "Descrizione:",
    "_%n year_::_%n years_" : ["%n anno","%n anni","%n anni"],
    "_%n month_::_%n months_" : ["%n mese","%n mesi","%n mesi"],
    "_%n day_::_%n days_" : ["%n giorno","%n giorni","%n giorni"],
    "_%n hour_::_%n hours_" : ["%n ora","%n ore","%n ore"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minuti","%n minuti"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s fa)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrizione: %s",
    "Where: %s" : "Dove: %s",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "Cancelled: %1$s" : "Annullato: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" è stato annullato",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s ha accettato il tuo invito",
    "%1$s has tentatively accepted your invitation" : "%1$s ha provvisoriamente accettato il tuo invito",
    "%1$s has declined your invitation" : "%1$s ha rifiutato il tuo invito",
    "%1$s has responded to your invitation" : "%1$s ha risposto al tuo invito",
    "Invitation updated: %1$s" : "Invito aggiornato: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s ha aggiornato l'evento \"%2$s\"",
    "Invitation: %1$s" : "Invito: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s vorrebbe invitarti in \"%2$s\"",
    "Organizer:" : "Organizzatore:",
    "Attendees:" : "Partecipanti:",
    "Title:" : "Titolo:",
    "Time:" : "Ora:",
    "Location:" : "Posizione:",
    "Link:" : "Collegamento:",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "More options …" : "Altre opzioni...",
    "More options at %s" : "Altre opzioni alle %s",
    "In a meeting" : "In una riunione",
    "Contacts" : "Contatti",
    "{actor} created address book {addressbook}" : "{actor} ha creato la rubrica {addressbook}",
    "You created address book {addressbook}" : "Hai creato la rubrica {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} ha eliminato la rubrica {addressbook}",
    "You deleted address book {addressbook}" : "Hai eliminato la rubrica {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} ha aggiornato la rubrica {addressbook}",
    "You updated address book {addressbook}" : "Hai aggiornato la rubrica {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} ha condiviso la rubrica {addressbook} con te",
    "You shared address book {addressbook} with {user}" : "Hai condiviso la rubrica {addressbook} con {actor}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} ha condiviso la rubrica {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} ha eliminato la condivisione della rubrica {addressbook} con te",
    "You unshared address book {addressbook} from {user}" : "Hai eliminato la condivisione della rubrica {addressbook} con {actor}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} ha eliminato la condivisone della rubrica {addressbook} da {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} ha eliminato la condivisone della rubrica {addressbook} da se stesso",
    "You shared address book {addressbook} with group {group}" : "Hai condiviso la rubrica {addressbook} con il gruppo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} ha condiviso la rubrica {addressbook} con il gruppo {group}",
    "You unshared address book {addressbook} from group {group}" : "Hai eliminato la condivisione della rubrica {addressbook} con il gruppo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} ha eliminato la condivisone della rubrica {addressbook} con il gruppo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} ha creato il contatto {card} nella rubrica {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Hai creato il contatto {card} nella rubrica {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} ha cancellato il contatto {card} nella rubrica {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Hai cancellato il contatto {card} nella rubrica {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} ha aggiornato il contatto {card} nella rubrica {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Hai aggiornato il contatto {card} nella rubrica {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Un <strong>contatto</strong> o <strong>rubrica</strong> sono stati modificati ",
    "Accounts" : "Account",
    "System address book which holds all accounts" : "Rubrica di sistema che contiene tutti gli account",
    "File is not updatable: %1$s" : "Il file non è aggiornabile: %1$s",
    "Could not write to final file, canceled by hook" : "Impossibile scrivere nel file finale, annullato da hook",
    "Could not write file contents" : "Impossibile scrivere il contenuto del file",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Errore durante la copia del file nella destinazione (copiato: %1$s, dimensione prevista del file: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Dimensione prevista del file %1$s, letto (dal client Nextcloud) e scritto (nell'archivio Nextcloud) %2$s. Potrebbe trattarsi di un problema di rete sul lato d'invio o di un problema di scrittura nell'archivio sul lato server.",
    "Could not rename part file to final file, canceled by hook" : "Impossibile rinominare il file di parte in file finale, annullato da hook",
    "Could not rename part file to final file" : "Impossibile rinominare il file di parte in file finale",
    "Failed to check file size: %1$s" : "Verifica della dimensione del file non riuscito: %1$s",
    "Could not open file" : "Impossibile aprire il file",
    "Encryption not ready: %1$s" : "Crittografia non pronta: %1$s",
    "Failed to open file: %1$s" : "Apertura del file non riuscito: %1$s",
    "Failed to unlink: %1$s" : "Scollegamento fallito: %1$s",
    "Invalid chunk name" : "Nome non valido per lo spezzone",
    "Could not rename part file assembled from chunks" : "Non è possibile rinominare il file assemblato da più spezzoni",
    "Failed to write file contents: %1$s" : "Scrittura del contenuto del file non riuscita: %1$s",
    "File not found: %1$s" : "File non trovato: %1$s",
    "System is in maintenance mode." : "Il sistema è in modalità di manutenzione.",
    "Upgrade needed" : "Aggiornamento necessario",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Il tuo %s deve essere configurato all'uso di HTTPS per poter usare CalDAV e CardDAV con iOS/macOS.",
    "Configures a CalDAV account" : "Configura un account CalDAV",
    "Configures a CardDAV account" : "Configura un account CardDAV",
    "Events" : "Eventi",
    "Tasks" : "Attività",
    "Untitled task" : "Attività senza titolo",
    "Completed on %s" : "Completata il %s",
    "Due on %s by %s" : "Scade il %s per %s",
    "Due on %s" : "Scade il %s",
    "No outstanding DAV system address book sync." : "Nessuna sincronizzazione della rubrica del sistema DAV in sospeso.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling occ dav:sync-system-addressbook." : "La sincronizzazione della rubrica del sistema DAV non è ancora stata eseguita poiché la tua istanza ha più di 1000 utenti o perché si è verificato un errore. Eseguila a mano chiamando occ dav:sync-system-addressbook.",
    "Migrated calendar (%1$s)" : "Calendario migrato (%1$s)",
    "Calendars including events, details and attendees" : "Calendari inclusi eventi, dettagli e partecipanti",
    "Contacts and groups" : "Contatti e gruppi",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Terminatore WebDAV",
    "Save" : "Salva",
    "Time zone:" : "Fuso orario:",
    "to" : "a",
    "Delete slot" : "Elimina slot",
    "No working hours set" : "Orari lavorativi non impostati",
    "Add slot" : "Aggiungi slot",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Sunday" : "Domenica",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Imposta automaticamente lo stato dell'utente su \"Non disturbare\" al di fuori della disponibilità per disattivare tutte le notifiche.",
    "Failed to load availability" : "Caricamento disponibilità non riuscito",
    "Saved availability" : "Disponibilità salvata",
    "Failed to save availability" : "Salvataggio disponibilità non riuscito",
    "Availability" : "Disponibilità",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se imposti il tuo orario di lavoro, gli altri utenti potranno vedere quando non sei in ufficio per organizzare una riunione.",
    "Calendar server" : "Server di calendari",
    "Send invitations to attendees" : "Invia gli inviti ai partecipanti",
    "Automatically generate a birthday calendar" : "Genera automaticamente un calendario dei compleanni",
    "Birthday calendars will be generated by a background job." : "Il calendario dei compleanni sarà generato con un'operazione in background.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Per cui non saranno disponibili immediatamente dopo l'abilitazione, ma saranno mostrati dopo qualche istante.",
    "Send notifications for events" : "Invia notifiche per eventi",
    "Notifications are sent via background jobs, so these must occur often enough." : "Le notifiche saranno inviate tramite operazioni in background, per cui tali operazioni devono essere eseguite abbastanza spesso.",
    "Send reminder notifications to calendar sharees as well" : "Invia notifiche di promemoria anche ai partecipanti al calendario",
    "Reminders are always sent to organizers and attendees." : "I promemoria vengono sempre inviati agli organizzatori e ai partecipanti.",
    "Enable notifications for events via push" : "Abilita notifiche per eventi tramite push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installa anche {calendarappstoreopen}l'applicazione Calendario{linkclose}, o {calendardocopen}connetti il tuo desktop e mobile per la sincronizzazione ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assicurati di configurare correttamente {emailopen}il server di posta{linkclose}.",
    "There was an error updating your attendance status." : "Si è verificato un errore durante l'aggiornamento dello stato della tua partecipazione.",
    "Please contact the organizer directly." : "Contatta direttamente l'amministratore.",
    "Are you accepting the invitation?" : "Accetti l'invito?",
    "Tentative" : "Provvisorio",
    "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente.",
    "%1$s has responded your invitation" : "%1$s ha risposto al tuo invito"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
