<?php
namespace Aws\MediaLive\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Elemental MediaLive** service.
 */
class MediaLiveException extends AwsException {}
