OC.L10N.register(
    "viewer",
    {
    "Viewer" : "العارض Viewer",
    "Simple file viewer with slideshow for media" : "عارض ملفات بسيط مع عارض شرائح slideshow ",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "اعرض أحدث الصور ومقاطع فيديو العطلات كما في الأفلام، و أظهِر لمحةً عن أحدث قصصك مباشرة ً من نكست كلاود خاصّتك، واختر أفضل GIF من مجموعتك بفضل خاصية معاينة ملفاتك المفضلة؛ وغير ذلك الكثير!",
    "Your browser does not support audio." : "متصفحك لا يدعم الصوت.",
    "Error loading {name}" : "خطأ في تحميل {name}",
    "Image saved" : "تمّ حفظ الصورة",
    "Error saving image" : "خطأ في حفظ الصور",
    "Unsaved changes" : "تغييرات لم يتم حفظها",
    "Drop changes" : "إسقاط التغييرات",
    "Your browser does not support videos." : "متصفحك لا يدعم الفيديوهات.",
    "Edit" : "تعديل",
    "Exit full screen" : "خروج من ملء الشاشة",
    "Full screen" : "ملء الشاشة",
    "Open sidebar" : "إفتح الشريط الجانبي",
    "Download" : "تنزيل",
    "Delete" : "حذف",
    "This file no longer exists" : "هذا الملف لم يعد موجوداً",
    "There is no plugin available to display this file type" : "لا يوجد مكون إضافي متاح لعرض هذا النوع من الملفات",
    "View" : "عرض",
    "Name" : "الاسم",
    "Save" : "Save",
    "Save as" : "حفظ باسم",
    "Back" : "عودة",
    "Loading …" : "التحميلُ جارٍ …",
    "Reset" : "إعادة الضبط",
    "All changes will be lost." : "ستفقد كل التغييرات.",
    "Are you sure you want to continue?" : "هل أنت متأكد أنك ترغب بالاستمرار؟",
    "Cancel" : "إلغاء",
    "Continue" : "متابعة",
    "Undo" : "تراجع",
    "Redo" : "إعادة",
    "Show original image" : "أعرُض الصور الأصلية",
    "Zoom in" : "تكبير",
    "Zoom out" : "تصغير",
    "Toggle zoom menu" : "تبديل قائمة التكبير و التصغير",
    "Adjust" : "إضبِط",
    "Fine-tune" : "مُناغمة file-tune",
    "Filters" : "فلاتر",
    "Watermark" : "علامة مائية",
    "Draw" : "أرسُم",
    "Resize" : "غَيِّرِ الحجم",
    "Invalid image." : "صورة غير صالحة.",
    "Error while uploading the image." : "خطأ أثناء رفع الصورة.",
    "are not images" : "ليست صوراً",
    "is not an image" : "ليست صورةً",
    "to be uploaded" : "ليتم تحميلها",
    "Crop" : "قَصْقِصْ",
    "Original" : "أصلي",
    "Custom" : "مُخصّص",
    "Square" : "مُربّع",
    "Landscape" : "وضع أُفُقي",
    "Portrait" : "وضع رأسي",
    "Ellipse" : "بيضاوي",
    "Classic TV" : "تلفاز كلاسيكي",
    "CinemaScope" : "إنفساح سينمائي CinemaScope",
    "Arrow" : "سهم",
    "Blur" : "تضبيب Blur",
    "Brightness" : "سطوع Brightness",
    "Contrast" : "تباين Contrast",
    "Un-flip X" : "فك الطوي الأفقي Un-flip X",
    "Flip X" : "طوي أفقي Flip X",
    "Un-flip Y" : "طوي رأسي Flip Y",
    "Flip Y" : "فك الطوي الرأسي Un-flip Y",
    "HSV" : "HSV",
    "Hue" : "تدرُّج لوني Hue",
    "Saturation" : "تشبُّع saturation",
    "Value" : "القيمة",
    "Image" : "صورة",
    "Importing …" : "إستيراد ...",
    "+ Add image" : "+ أضِف صورةً",
    "Line" : "خط",
    "Pen" : "قلم",
    "Polygon" : "مُضلّع",
    "Sides" : "الجوانب",
    "Rectangle" : "مستطيل",
    "Corner Radius" : "نصف قطر الزاوية Corner Radius",
    "Width in pixels" : "العرض بالبكسل",
    "Height in pixels" : "الارتفاع بالبكسل",
    "Toggle ratio lock" : "تبديل قُفْل النِّسبَة ratio lock",
    "Reset to original image size" : "إرجاع الصورة لحجمها الأصلي",
    "Rotate" : "تدوير",
    "Text" : "نص",
    "Text spacing" : "تباعد النص",
    "Text alignment" : "محاذاة النص",
    "Font family" : "عائلة الخطوط",
    "Size" : "الحجم",
    "Letter spacing" : "تباعد الحروف",
    "Line height" : "إرتفاع السطر",
    "Warmth" : "الشِّدَّة warmth",
    "+ Add watermark" : "+ أضِف العلامة المائية",
    "Choose watermark type" : "إختر نوع العلامة المائية",
    "Upload watermark" : "رفع علامة مائية",
    "Add as text" : "أضِف كنصٍّ",
    "Padding" : "الحشو padding",
    "Shadow" : "تظليل shadow",
    "Horizontal" : "أفُقِي",
    "Vertical" : "رأسِي",
    "Opacity" : "التعتيم opacity",
    "Position" : "الموضع position",
    "Stroke" : "شطب stroke",
    "Save image as" : "حفظ الصورة باسم",
    "Extension" : "الامتداد",
    "Name is required." : "خانة الاسم لازمةٌ.",
    "Quality" : "الجودة",
    "Saved image size (width x height)" : "حجم الصورة المحفوظة (العرض × الارتفاع)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "لاحظ أن مساحة الاقتصاص crop المحددة أقل من الحجم المطبق مما قد يتسبب في انخفاض الجودة",
    "Actual size (100%)" : "الحجم الفعلي (100%)",
    "Fit size" : "الحجم الملائم fit size",
    "\"{fileName}\"" : "\"{fileName}\""
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
