OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "ກ໋ອບປີ້ແລ້ວ",
    "Not supported!" : "ບໍ່ຊັບຟອດ",
    "Press Ctrl-C to copy." : "ກົດ Ctrl-C ເພື່ອ copy",
    "Shares" : "ການແບ່ງປັນ",
    "Copy" : "ສຳເນົາ"
},
"nplurals=1; plural=0;");
