OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "First run wizard" : "Ensimmäisen käyttökerran avustaja",
    "Add your profile information! For example your email is needed to receive notifications." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen ja salasanan palauttamiseen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
    "App recommendation: Nextcloud Calendar" : "Sovellussuositus: Nextcloud-kalenteri",
    "Schedule work & meetings, synced with all your devices." : "Aikatauluta työsi ja tapaamisesi synkronoidusti kaikkien laitteitesi välillä.",
    "App recommendation: Nextcloud Contacts" : "Sovellussuositus: Nextcloud-yhteystiedot",
    "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
    "App recommendation: Nextcloud Mail" : "Sovellussuositus: Nextcloud-sähköposti",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
    "App recommendation: Tasks" : "Sovellussuositus: Tehtävät",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synkronoit tehtäviä eri laitteista Nextcloudiisi ja muokkaa niitä netissä.",
    "App recommendation: Deck" : "Sovellussuositus: Pakka",
    "Kanban style organization for personal planning and team projects." : "Kanban-tyylistä organisointia henkilökohtaiseen suunnitteluun ja ryhmäprojekteihin.",
    "App recommendation: Forms" : "Sovellussuositus: Lomakkeet",
    "Simple surveys and questionnaires, self-hosted" : "Helppoja ja yksinkertaisia kyselyitä omalla palvelimella",
    "App recommendation: Recognize" : "Sovellussuositus: Tunnista",
    "Smart media tagging for Nextcloud" : "Median älykästä merkitsemistä tunnisteilla Nextcloudille",
    "App recommendation: Group folders" : "Sovellussuositus: Ryhmäkansiot",
    "Admin-configured folders shared by everyone in a group." : "Ylläpitäjän määrittämät kansiot jaettuina kaikille ryhmän jäsenille.",
    "About" : "Tietoja",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloudin ensimmäisen käyttökerran avustaja",
    "Welcome to {cloudName}!" : "Tervetuloa pilveen {cloudName}!",
    "Privacy" : "Yksityisyys",
    "Community" : "Yhteisö",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s mahdollistaa pääsyn tiedostoihisi missä hyvänsä oletkin. Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suurimmille alustoille veloituksetta.",
    "Desktop client" : "Työpöytäsovellus",
    "Android app on Google Play Store" : "Android-sovellus Google Play Storessa",
    "Android app on F-Droid" : "Android-sovellus F-Droidissa",
    "iOS app" : "iOS-sovellus",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Määritä synkronointi käyttäen <a href=\"%s\">sovelluskohtaisia salasanoja</a>. Näin voit kumota käyttöoikeuden, jos satut esimerkiksi kadottamaan tietyn laitteesi",
    "Connect other apps to %s" : "Yhdistä muita sovelluksia pilveen %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Synkronointisovellusten lisäksi voit yhdistää minkä tahansa WebDAV-, CalDAV- ja CardDAV-yhteyskäytäntöjä tukevan ohjelmiston pilveen %s",
    "Connect your calendar" : "Yhdistä kalenteriisi",
    "Connect your contacts" : "Yhdistä yhteystietoihisi",
    "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
    "Download macOS/iOS configuration profile" : "Lataa macOS-/iOS-asetusprofiili",
    "Server address" : "Palvelimen osoite",
    "Use this link to connect your apps and desktop client to this server:" : "Käytä tätä linkkiä yhdistääksesi sovellukset ja työpöytäsovelluksen tähän palvelimeen:",
    "Copy link" : "Kopioi linkki",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Start using {cloudName}" : "Aloita pilven {cloudName} käyttäminen",
    "Extend your cloud" : "Laajenna pilveäsi",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Löydä yli 100 eri sovellusta Nextcloud-sovelluskaupasta pilvesi muokkaamiseksi:",
    "Groupware apps like Calendar, Contacts, Mail" : "Työryhmäohjelmistot kuten kalenteri, yhteystiedot ja sähköposti",
    "Communication with Nextcloud Talk" : "Yhteydenpito Nextcloud Talkilla",
    "Collaboration apps for document editing" : "Yhteistyösovellukset asiakirjojen muokkaukseen",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Tietoturva- ja tunnistautumisominaisuuksia kuten kaksivaiheinen tunnistautuminen, kertakirjautuminen ja suoja kiristysohjelmia vastaan",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Paljon muuta kuten musiikkisoitin, salasanahallinta, kanban-sovellus, lataushallinta ja markdown-muokkain",
    "Browse the App Store" : "Selaa sovelluskauppaa",
    "Stay in sync" : "Pysy synkronoituna",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud mahdollistaa pääsyn tiedostoihisi sijainnistasi riippumatta.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suosituimmille alustoille ilman kustannuksia!",
    "Connect your desktop apps to %s" : "Yhdistä työpöytäsovelluksesi pilveen %s",
    "Get help" : "Saa apua",
    "Start contributing" : "Anna oma panoksesi",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Haluatko tietyn parannuksen Nextcloudiin? Löysitkö ongelman? Haluatko kääntää, mainostaa tai dokumentoida Nextcloudia?",
    "Become part of the Community" : "Ryhdy osaksi yhteisöä",
    "Enterprise support" : "Yritystuki",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "Jos käytät Nextcloudia erittäin tärkeässä ympäristössä, missä turvallisuus ja määräystenmukaisuus merkitsevät, tarvitset Nextcloud Enterprisen tuomaa varmuutta.",
    "Learn more about Nextcloud Enterprise" : "Lue lisää Nextcloudin Enterprise-versiosta",
    "Get more information" : "Hanki lisätietoja",
    "The Nextcloud documentation for home users:" : "Nextcloud-ohjeet kotikäyttäjille:",
    "User manual" : "Käyttäjän ohje",
    "Admin manual" : "Ylläpitäjän ohje",
    "Developer manual" : "Kehittäjän ohje",
    "You can also ask for help in our community support channels:" : "Voit kysyä apua myös yhteisön tukikanavilta:",
    "the Nextcloud forums" : "Nextcloud-keskustelualueet",
    "A safe home for all your data" : "Turvallinen koti kaikille tiedoillesi",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud asettaa tietosi sinun hallintaasi. Talleta asiakirjat, kalenteri, yhteystiedot ja kuvat organisaatiosi tarjoamalle palvelimelle, kotipalvelimellesi, Nextcloudin yhteistyökumppanien palvelimille tai luottamaasi palvelinkeskukseen.",
    "Host your data and files where you decide" : "Säilytä tietosi ja tiedostosi missä itse haluat",
    "Open standards and interoperability" : "Avoimet standardit ja yhteentoimivuus",
    "100%% open source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
    "Learn more about %s" : "Lisätietoja - %s",
    "This Nextcloud is on version %s" : "Tämä Nextcloud on versiossa %s"
},
"nplurals=2; plural=(n != 1);");
