OC.L10N.register(
    "photos",
    {
    "Photos" : "ფოტოები",
    "Videos" : "ვიდეოები",
    "Folders" : "დირექტორიები",
    "Favorites" : "რჩეულები",
    "Shared with you" : "გაზიარებული თქვენთან",
    "Tags" : "ტეგები",
    "Back" : "უკან",
    "Save" : "შენახვა",
    "Shared by" : "გამზიარებელი",
    "Favorite" : "რჩეული",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add" : "დამატება",
    "Details" : "დეტალები"
},
"nplurals=2; plural=(n!=1);");
