OC.L10N.register(
    "files_rightclick",
    {
    "Unselect all" : "取消全选",
    "Share folder" : "共享文件夹",
    "Share file" : "共享文件",
    "Select" : "选择",
    "Copied !" : "已复制！",
    "Right click" : "右键单击",
    "Right click menu for Nextcloud" : "Nextcloud 的右键菜单",
    "This app allows users and developers to have a right click menu. Simply use the RightClick object to quickly create context menus. The Files app already shows the actions menu when right clicking on files and folders." : "此应用允许用户和开发者拥有一个右键菜单。简单使用右键单击对象来快速创建上下文菜单。在文件应用中右击文件和文件夹将会显示动作菜单。"
},
"nplurals=1; plural=0;");
