#header{background:rgba(0,0,0,0) !important;--color-header: rgba(24, 24, 24, 1)}#body-user.dashboard--dark #header{--color-header: rgba(255, 255, 255, 1)}#header:before{content:" ";display:block;position:absolute;background-image:linear-gradient(180deg, var(--color-header) 0%, transparent 100%);width:100%;height:70px;top:0;margin-top:-70px;transition:margin-top var(--animation-slow)}#body-user.dashboard--scrolled #header:before{margin-top:0}#body-user.theme--highcontrast #header{background-color:var(--color-header) !important}#body-user.theme--highcontrast #header:before{display:none}#content{padding-top:0 !important}#appmenu li a.active::before,#appmenu li:hover a::before,#appmenu li:hover a.active::before,#appmenu li a:focus::before{display:none !important}/*# sourceMappingURL=dashboard.css.map */
