OC.L10N.register(
    "logreader",
    {
    "Time" : "Ora",
    "Show details" : "Mostrar detalhs",
    "Info" : "Info",
    "Warning" : "Avertiment",
    "Error" : "Error",
    "Copy" : "Copiar",
    "Copy raw" : "Còpia bruta",
    "Copy formatted" : "Còpia formatada"
},
"nplurals=2; plural=(n > 1);");
