OC.L10N.register(
    "admin_audit",
    {
    "Auditing / Logging" : "Auditas / Registravimas",
    "Provides logging abilities for Nextcloud such as logging file accesses or otherwise sensitive actions." : "Suteikia „Nextcloud“ registravimo galimybes, pvz., Prieigų prie failų registravimą ar kitus neskelbtinus veiksmus."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
