OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "First run wizard" : "Майстер першого запуску",
    "Add your profile information! For example your email is needed to receive notifications." : "Додайте інформацію свого профілю! Наприклад, ваша електронна адреса потрібна для отримання сповіщень.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Додайте інформацію свого профілю! Наприклад, ваша електронна адреса потрібна для отримання сповіщень і скидання пароля.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Додайте інформацію в свій профіль! Встановіть зображення профілю та повне ім'я для полегшення розпізнавання у всіх функціях.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Додайте інформацію свого профілю! Встановіть повне ім’я для легшого розпізнавання всіх функцій.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Додайте інформацію свого профілю! Встановіть зображення профілю для легшого розпізнавання всіх функцій.",
    "App recommendation: Nextcloud Calendar" : "Рекомендований застосунок: \"Календар\" від Nextcloud",
    "Schedule work & meetings, synced with all your devices." : "Планування роботи та зустрічей із синхронізацією зі всіма вашими пристроями",
    "App recommendation: Nextcloud Contacts" : "Рекомендований застосунок: \"Контакти\" від Nextcloud",
    "Keep your colleagues and friends in one place without leaking their private info." : "Створіть спільний безпечний простір для співпраці та обміну даними з вашими колегами та друзями.",
    "App recommendation: Nextcloud Mail" : "Рекомендований застосунок: \"Пошта\" від Nextcloud",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Простий застосунок електронної пошти, добре інтегрований з Файлами, Контактами та Календарем.",
    "App recommendation: Tasks" : "Рекомендований застосунок: \"Завдання\"",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Синхронізуйте завдання з різних пристроїв із вашим Nextcloud і редагуйте їх онлайн.",
    "App recommendation: Deck" : "Рекомендований застосунок: \"Deck\"",
    "Kanban style organization for personal planning and team projects." : "Організація в стилі канбан для особистого планування та командних проектів.",
    "App recommendation: Forms" : "Рекомендований застосунок: \"Форми\"",
    "Simple surveys and questionnaires, self-hosted" : "Прості опитування та анкети, розміщені самостійно",
    "App recommendation: Recognize" : "Рекомендація програми: Recognize",
    "Smart media tagging for Nextcloud" : "Інтелектуальне позначення мультимедійного контенту для Nextcloud",
    "App recommendation: Group folders" : "Рекомендація щодо програми: Group folders",
    "Admin-configured folders shared by everyone in a group." : "Каталоги, які було налаштовано адміністратором, доступні для всіх у групі.",
    "About" : "Про програму",
    "A welcome and introduction wizard for Nextcloud" : "Ласкаво просимо в майстер знайомства з Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Ця програма активує спливаюче вікно, коли користувач вперше входить до Nextcloud. Це вікно вітає нових користувачів у Nextcloud і містить посилання на стандартний клієнт для PC, програму Android та програму iOS. У вікні також показано посилання для доступу до Nextcloud через WebDAV. У будь-який час майстер першого запуску можна відкрити знову за посиланням \"Про програму\" у меню налаштувань. \nМайстер першого запуску можна налаштувати відповідно до конкретних цілей дизайну або змінити посилання та повідомлення. Створіть відповідну тему, дотримуючись документації з оформлення, та змініть зовнішній вигляд цього майстра легко. Додаткову інформацію можна знайти в документації майстра першого запуску, а також у документації щодо створення тем.",
    "Go to previous page" : "На попередню сторінку",
    "Close dialog" : "Закрити діалог",
    "Nextcloud on all your devices" : "Nextcloud на всіх ваших пристроях",
    "More about Nextcloud" : "Докладно про Nextcloud",
    "Get started!" : "Почнімо!",
    "Download on Apple app store" : "Звантажити з Apple AppStore",
    "Download on Google play store" : "Звантажити з Google PlayStore",
    "Welcome to {cloudName}!" : "Вітаємо в {cloudName}!",
    "A collaboration platform that puts you in control" : "Платформа для співпраці під вашим контролем",
    "Privacy" : "Приватність",
    "Host your data and files where you decide." : "Розміщуйте ваші дані та файли у зручному для вас місці.",
    "Productivity" : "Продуктивність.",
    "Collaborate and communicate across any platform." : "Співпрацюйте та спілкуйтеся на різних платформах.",
    "Interoperability" : "Сумісність",
    "Import and export anything you want with open standards." : "Імпортуйте та експортуйте дані із застосуванням відкритих стандартів.",
    "Community" : "Спільнота",
    "Enjoy constant improvements from a thriving open-source community." : "Отримуйте постійні удосконалення завдяки спільноті розробників відкритого ПЗ.",
    "Seamless integration with your devices." : "Прозора інтеграція всіх ваших пристроїв",
    "Desktop app ↗" : "Настільний застосунок ↗",
    "Download For Windows, Mac OS and Linux." : "Звантажити для Windows, Mac OS та Linux.",
    "Calendar and contacts ↗" : "Календар та контакти ↗",
    "Connect your calendar and contacts with your devices." : "З'єднайте ваш календар та адресну книгу з вашими пристроями.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Синхронізовуйте ваші файли між різними пристроями, на яких встановлено настільні та мобільні застосунки, приєднуйте ваші календарі, адресні книги.",
    "Explore more apps ↗" : "Знайти більше застосунків ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Доповніть функціональність Nextcloud застосунками, які створено спільнотою розробників.",
    "Get involved! ↗" : "Приєднатися! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Станьте частиною спільноти, яка розробляє, оформлює, перекладає та просуває Nextcloud!",
    "Need help? ↗" : "Потрібна допомога? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Дізнайтеся більше про налаштування хмари Nexcloud у посібниках для адміністраторів, користувачів та розробників.",
    "For large organisations ↗" : "Для великих організацій ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Отримуйте Nextcloud для Бізнесу для середовищ, які мають потребу у постійній підтримці, а також де розширена безпека та відповідність мають критичне значення.",
    "Get the apps to sync your files" : "Отримати застосунки для синхронізації ваших файлів",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "За допомогою хмари %s ви можете мати доступ до ваших файлів, де б ви не перебували. Наші прості у використанні стільничі та мобільні застосунки безкоштовно доступні для всіх основних платформ.",
    "Desktop client" : "Клієнт для ПК",
    "Android app on Google Play Store" : "Застосунок для Android у каталозі Google Play",
    "Android app on F-Droid" : "Застосунок Android у F-Droid",
    "iOS app" : "iOS застосунок",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Налаштуйте клієнти синхронізації за допомогою <a href=\"%s\">пароля програми</a>. Таким чином ви зможете переконатися, що зможете скасувати доступ у разі втрати пристрою.",
    "Connect other apps to %s" : "Під'єднайте інші застосунки до хмари %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Крім мобільних застосунків та клієнта для ПК, ви можете під'єднати будь-яке інше програмне забезпечення, яке підтримує протоколи WebDAV/CalDAV/CardDAV, до %s.",
    "Connect your calendar" : "Приєднайте ваш календар",
    "Connect your contacts" : "Приєднайте вашу адресну книгу",
    "Access files via WebDAV" : "Доступ до файлів із WebDAV",
    "Download macOS/iOS configuration profile" : "Звантажте профіль конфігурації для macOS/iOS",
    "Server address" : "Адреса сервера",
    "Use this link to connect your apps and desktop client to this server:" : "Посилання на під'єднання застосунків та клієнта ПК чи смартфону до цього сервера:",
    "Copy link" : "Копіювати посилання",
    "Copy to clipboard" : "Копіювати до буферу обміну",
    "Start using {cloudName}" : "Почніть використовувати {cloudName}",
    "Extend your cloud" : "Розширте свою хмару",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Крамниця Nextcloud містить понад 100 застосунків, які допоможуть організувати ваш хмарний простір:",
    "Groupware apps like Calendar, Contacts, Mail" : "Застосунки для робочих груп, як от Календар, Контакти, Пошта",
    "Communication with Nextcloud Talk" : "Спілкування за допомогою Nextcloud Talk",
    "Collaboration apps for document editing" : "Спільне редагування документів",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Авторизація в хмарі та безпека, такі як двофакторна авторизація, єдина точка входу та захист від програм-вимагачів",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Багато інших корисних застсунків, наприклад, музичний плеєр, менеджер паролів, робота із завданнями, менеджер завантажень або редактор текстів з підтримкою розмітки.",
    "Browse the App Store" : "Перейти до AppStore",
    "Stay in sync" : "Залишайтеся на зв'язку",
    "Nextcloud gives you access to your files wherever you are." : "Хмара на основі Nextcloud допоможе організувати доступ до ваших файлів незалежно від місця вашого перебування.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Вам також доступні безкоштовні застосунки для ПК та мобільних пристроїв для основних платформ.",
    "Connect your desktop apps to %s" : "Під'єднати ваші застосуноки до %s",
    "Get help" : "Отримати допомогу",
    "Start contributing" : "Допоможіть покращити",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Ви хочете отримати певне покращення в Nextcloud? Ви знайшли проблему? Хочете допомогти перекладати, рекламувати чи документувати Nextcloud?",
    "Become part of the Community" : "Станьте частиною спільноти",
    "Enterprise support" : "Для підприємств",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "Якщо ви запускаєте Nextcloud у критично важливому середовищі, де безпека та відповідність є важливими, вам потрібна впевненість Nextcloud Enterprise.",
    "Learn more about Nextcloud Enterprise" : "Дізнайтеся більше про Nextcloud Enterprise",
    "Get more information" : "Отримати більше інформації",
    "The Nextcloud documentation for home users:" : "Документація з користування хмарою Nextcloud для домашніх користувачів:",
    "User manual" : "Посібник користувача",
    "Admin manual" : "Керівництво адміністратора",
    "Developer manual" : "Інструкція розробника",
    "You can also ask for help in our community support channels:" : "Ви також можете звернутися по допомогу до спільноти користувачів та розробників:",
    "the Nextcloud forums" : "Форуми Nextcloud",
    "A safe home for all your data" : "Безпечний дім для Ваших даних",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud уможливлює доступ до ваших даних під суцільним вашим контролем. Зберігайте документи, календарі, контакти та фотографії у хмарі вашої компанії або вдома чи в одного з наших постачальників або в центрі обробки даних, який вам відомий.",
    "Host your data and files where you decide" : "Ваші дані та файли розміщуватимуться там, де ви вирішите",
    "Open standards and interoperability" : "Відкриті стандарти та сумісність",
    "100%% open source & community-focused" : "100%% відкритий код, який підтримує спільнота фахівців та ентузіастів",
    "Learn more about %s" : "Дізнайтеся більше про %s",
    "This Nextcloud is on version %s" : "У вас встановлено Nextcloud версії %s"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
