OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Tên quá dài",
    "The given web address is too long" : "Địa chỉ web quá dài",
    "The given web address is not a valid URL" : "Địa chỉ web được cấp không phải là một đường dân URL khả dụng",
    "The given legal notice address is too long" : "Địa chỉ thông cáo pháp lý được cấp quá dài",
    "The given legal notice address is not a valid URL" : "Địa chỉ thông cáo pháp lý được cấp không phải là một đường dẫn URL khả dụng",
    "The given privacy policy address is too long" : "Địa chỉ chính sách riêng tư quá dài",
    "The given privacy policy address is not a valid URL" : "Địa chỉ chính sách riêng tư được cấp không phải là một đường dẫn URL khả dụng",
    "The given slogan is too long" : "Khẩu hiệu quá dài",
    "The given color is invalid" : "Màu không hợp lệ",
    "Disable-user-theming should be true or false" : "Vô hiệu hóa chủ đề người dùng phải đúng hoặc sai",
    "Saved" : "Đã lưu",
    "Invalid app given" : "Đã cung cấp ứng dụng không hợp lệ",
    "Invalid type for setting \"defaultApp\" given" : "Loại cài đặt 'defaultApp' đã cho không hợp lệ",
    "Invalid setting key" : "Phím cài đặt không hợp lệ",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên ổ đĩa",
    "A PHP extension stopped the file upload" : "Một phần mở rộng của PHP đã dừng tải tệp lên",
    "No file uploaded" : "Không có tệp nào được tải lên",
    "Failed to clean up the old administration theming images folder" : "Không thể dọn sạch thư mục hình ảnh theo chủ đề quản trị cũ",
    "Failed to clean up the old administration image folder" : "Không thể dọn sạch thư mục hình ảnh quản trị cũ",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Bạn đang sử dụng 1 chủ đề riêng. Các thiết lập của ứng dụng Chủ đề có thể bị ghi đè bởi nó.",
    "Theming" : "Điều chỉnh giao diện",
    "Appearance and accessibility" : "Chủ đề",
    "Dark theme with high contrast mode" : "Chủ đề tối với chế độ tương phản cao",
    "Enable dark high contrast mode" : "Bật chế độ tương phản cao tối",
    "Similar to the high contrast mode, but with dark colours." : "Tương tự như chế độ tương phản cao nhưng có màu tối.",
    "Dark theme" : "Chế độ ban đêm",
    "Enable dark theme" : "Bật chế độ ban đêm",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Một chủ đề tối để làm dịu mắt bạn bằng cách giảm độ sáng và độ sáng tổng thể.",
    "System default theme" : "Chủ đề mặc định của hệ thống",
    "Enable the system default" : "Kích hoạt mặc định hệ thống",
    "Using the default system appearance." : "Sử dụng giao diện hệ thống mặc định.",
    "Dyslexia font" : "Chứng khó đọc",
    "Enable dyslexia font" : "Bật chế độ dành cho người gặp chứng khó đọc",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic là một kiểu chữ / phông chữ miễn phí được thiết kế để giảm thiểu một số lỗi đọc phổ biến do chứng khó đọc gây ra.",
    "High contrast mode" : "Chế độ tương phản cao",
    "Enable high contrast mode" : "Bật chế độ tương phản cao",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Chế độ tương phản cao giúp bạn dễ dàng điều hướng và phân biệt vị trí các mục chính xác hơn. Chất lượng hình ảnh sẽ giảm nhưng độ rõ sẽ được tăng lên.",
    "Light theme" : "Chủ đề nhẹ nhàng",
    "Enable the default light theme" : "Bật chủ đề ánh sáng mặc định",
    "The default light appearance." : "Sự xuất hiện ánh sáng mặc định.",
    "Legal notice" : "Thông cáo pháp lý",
    "Privacy policy" : "Chính sách riêng tư",
    "Adjust the Nextcloud theme" : "Tinh chỉnh chủ đề Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Điều chỉnh giao diện cho phép bạn có thể dễ dàng tùy biến bố cục trình bày của hệ thống. Khi thực hiện nó sẽ hiện hữu đối với tất cả người dùng",
    "Advanced options" : "Tùy chọn nâng cao",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Cài đặt tiện ích mở rộng ImageMagick PHP có hỗ trợ hình ảnh SVG để tự động tạo favicon dựa trên logo và màu sắc đã tải lên.",
    "Name" : "Tên",
    "Web link" : "Liên kết web",
    "a safe home for all your data" : "một ngôi nhà an toàn cho tất cả dữ liệu của bạn",
    "Slogan" : "Khẩu hiệu",
    "Color" : "Màu sắc",
    "Logo" : "Logo",
    "Upload new logo" : "Tải lên logo mới",
    "Background and login image" : "Hình nền và hình ảnh đăng nhập",
    "Upload new background and login image" : "Upload new background and login image",
    "Legal notice link" : "Liên kết Thông cáo pháp lý",
    "Privacy policy link" : "Liên kết Chính sách riêng tư",
    "Header logo" : "Logo đầu trang",
    "Upload new header logo" : "Tải lên logo đầu trang mới",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Tải lên bộ Favicon mới",
    "User settings" : "Thiết lập người dùng",
    "Disable user theming" : "Tắt chủ đề người dùng",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Mặc dù bạn có thể chọn và tùy chỉnh phiên bản của mình nhưng người dùng có thể thay đổi nền và màu sắc của họ. Nếu bạn muốn thực thi tùy chỉnh của mình, bạn có thể bật tính năng này.",
    "Background" : "Nền",
    "Customization has been disabled by your administrator" : "Tùy chỉnh đã bị quản trị viên của bạn vô hiệu hóa",
    "Set a custom background" : "Đặt nền tùy chỉnh",
    "Keyboard shortcuts" : "Phím tắt",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Trong một số trường hợp, phím tắt có thể ảnh hưởng đến các công cụ trợ năng. Để cho phép tập trung vào công cụ của bạn một cách chính xác, bạn có thể tắt tất cả các phím tắt tại đây. Điều này cũng sẽ vô hiệu hóa tất cả các phím tắt có sẵn trong ứng dụng.",
    "Disable all keyboard shortcuts" : "Vô hiệu hóa tất cả các phím tắt",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Sự truy cập đa dạng là rất quan trọng với chúng tôi. Chúng tôi tuân theo các tiêu chuẩn mạng và kiểm tra để khiến mọi thứ đều có thể sử dụng được ngay cả khi không có chuột, và hỗ trợ những phần mềm hỗ trợ như đọc màn hình. Chúng tôi hướng đến sự tương thích với {guidelines}Nguyên Tắc Truy Cập Cho Nội Dung Mạng{linkend} 2.1  ở cấp độ AA, với chế độ tương phản cao là AAA",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Nếu bạn phát hiện bất kỳ vấn đề nào, đừng ngần ngại báo cáo chúng trên {issuetracker}trình theo dõi vấn đề của chúng tôi{linkend}. Và nếu bạn muốn tham gia, hãy tham gia {designteam}nhóm thiết kế của chúng tôi{linkend}!",
    "Move up" : "Di chuyển lên",
    "Move down" : "Di chuyển xuống",
    "Custom background" : "Tùy chỉnh nền",
    "Default background" : "Nền mặc định",
    "Change color" : "Thay đổi màu sắc",
    "No background" : "Không có nền",
    "Select a background from your files" : "Chọn nền từ tập tin của bạn",
    "Select background" : "Chọn phông nền",
    "No background has been selected" : "Không có nền nào được chọn",
    "Theme selection is enforced" : "Lựa chọn chủ đề được thực thi",
    "Navigation bar settings" : "Cài đặt thanh điều hướng",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Bạn có thể định cấu hình thứ tự ứng dụng được sử dụng cho thanh điều hướng. Mục nhập đầu tiên sẽ là ứng dụng mặc định, được mở sau khi đăng nhập hoặc khi nhấp vào logo.",
    "The default app can not be changed because it was configured by the administrator." : "Không thể thay đổi ứng dụng mặc định vì nó đã được quản trị viên định cấu hình.",
    "The app order was changed, to see it in action you have to reload the page." : "Thứ tự ứng dụng đã được thay đổi, để xem nó hoạt động bạn phải tải lại trang.",
    "Reset default app order" : "Đặt lại thứ tự ứng dụng mặc định",
    "Could not set the app order" : "Không thể đặt thứ tự ứng dụng",
    "Could not reset the app order" : "Không thể đặt lại thứ tự ứng dụng",
    "Default app" : "Ứng dụng mặc định",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Ứng dụng mặc định là ứng dụng ví dụ: được mở sau khi đăng nhập hoặc khi nhấp vào biểu tượng trong menu.",
    "Use custom default app" : "Sử dụng ứng dụng mặc định tùy chỉnh",
    "Global default app" : "Ứng dụng mặc định toàn cầu",
    "Global default apps" : "Ứng dụng mặc định toàn cầu",
    "Default app priority" : "Ưu tiên ứng dụng mặc định",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Nếu một ứng dụng không được bật cho người dùng thì ứng dụng tiếp theo có mức độ ưu tiên thấp hơn sẽ được sử dụng.",
    "Could not set global default apps" : "Không thể đặt ứng dụng mặc định chung",
    "Select a custom color" : "Chọn màu tùy chỉnh",
    "Reset to default" : "Đặt lại về mặc định",
    "Upload" : "Tải lên",
    "Remove background image" : "Xóa bỏ ảnh nền",
    "Loading preview…" : "Đang tải mục xem trước...",
    "Admin" : "Quản trị viên",
    "Error uploading the file" : "Lỗi tải tập tin lên",
    "Name cannot be empty" : "Tên không thể trống",
    "Migrate and clean up admin theming images" : "Di chuyển và dọn dẹp hình ảnh chủ đề quản trị viên",
    "Failed to clean up the old admin theming images folder" : "Không thể dọn sạch thư mục hình ảnh chủ đề quản trị viên cũ",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Trong một số trường hợp, phím tắt có thể ảnh hưởng đến các công cụ trợ năng. Để cho phép tập trung vào công cụ của bạn một cách chính xác, bạn có thể tắt tất cả các phím tắt tại đây. Điều này cũng sẽ vô hiệu hóa tất cả các phím tắt có sẵn trong ứng dụng.",
    "Pick from Files" : "Chọn từ Tệp",
    "Default image" : "Hình ảnh mặc định",
    "Custom color" : "Tùy chỉnh màu",
    "Plain background" : "Nền đơn giản",
    "Insert from {productName}" : "Chèn từ {productName}",
    "Open documentation" : "Mở tài liệu",
    "https://…" : "https://…",
    "Upload new login background" : "Tải lên ảnh nền trang đăng nhập mới",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Mặc dù bạn có thể chọn và tùy chỉnh phiên bản của mình nhưng người dùng có thể thay đổi nền và màu sắc của họ. Nếu bạn muốn thực thi tùy chỉnh của mình, bạn có thể chọn hộp này.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Cài đặt phần mở rộng PHP Imagemagick với hỗ trợ cho hình ảnh SVG để tự động tạo bộ favicon dựa trên màu và logo được tải lên"
},
"nplurals=1; plural=0;");
