OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiquetas",
    "Tagged files" : "Ficheiros etiquetados",
    "Select tags to filter by" : "Selecionar etiquetas para filtrar",
    "Please select tags to filter by" : "Por favor, selecione etiquetas para filtrar",
    "No files found for the selected tags" : "Não foram encontrados ficheiros para as etiquetas selecionadas",
    "<strong>System tags</strong> for a file have been modified" : "As <strong>etiquetas do Sistema</strong> para um ficheiro foram alteradas",
    "You assigned system tag %3$s" : "Atribuiu a etiqueta do sistema %3$s",
    "%1$s assigned system tag %3$s" : "%1$s atribuiu a etiqueta do sistema %3$s",
    "You unassigned system tag %3$s" : "Removeu a etiqueta do sistema %3$s",
    "%1$s unassigned system tag %3$s" : "%1$s removeu a etiqueta do sistema %3$s",
    "You created system tag %2$s" : "Criou a etiqueta do sistema %2$s",
    "%1$s created system tag %2$s" : "%1$s criou a etiqueta do sistema %2$s",
    "You deleted system tag %2$s" : "Eliminou etiqueta do sistema %2$s",
    "%1$s deleted system tag %2$s" : "%1$s eliminou a etiqueta do sistema %2$s",
    "You updated system tag %3$s to %2$s" : "Atualizou a etiqueta do sistema %3$s para %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atualizou a etiqueta %3$s para %2$s",
    "You assigned system tag %3$s to %2$s" : "Atribuiu a etiqueta do sistema %3$s para %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s atribuiu a etiqueta %3$s para %2$s",
    "You unassigned system tag %3$s from %2$s" : "Removeu a etiqueta do sistema %3$s de %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s removeu a etiqueta do sistema %3$s de %2$s",
    "%s (restricted)" : "%s (limitado)",
    "%s (invisible)" : "%s (invisível)",
    "Name" : "Nome",
    "No files in here" : "Nenhuns ficheiros aqui",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Size" : "Tamanho",
    "Modified" : "Modificado"
},
"nplurals=2; plural=(n != 1);");
