OC.L10N.register(
    "provisioning_api",
    {
    "Logged in user must be an administrator or have authorization to edit this setting." : "L'usuari que ha iniciat la sessió ha de ser administrador o tenir autorització per a editar aquest paràmetre.",
    "User already exists" : "L'usuari ja existeix",
    "Email confirmation" : "Confirmació de l'adreça electrònica",
    "To enable the email address %s please click the button below." : "Per a habilitar l'adreça electrònica %s, feu clic en el botó següent.",
    "Confirm" : "Confirma",
    "Email was already removed from account and cannot be confirmed anymore." : "L'adreça electrònica ja s'ha suprimit del compte i ja no es pot confirmar.",
    "Could not verify mail because the token is expired." : "No s'ha pogut verificar l'adreça electrònica perquè el testimoni ha caducat.",
    "Could not verify mail because the token is invalid." : "No s'ha pogut verificar l'adreça electrònica perquè el testimoni no és vàlid.",
    "An unexpected error occurred. Please contact your admin." : "S'ha produït un error inesperat. Contacteu amb l'administrador.",
    "Email confirmation successful" : "S'ha confirmat l'adreça electrònica",
    "Provisioning API" : "API d'aprovisionament",
    "This application enables a set of APIs that external systems can use to manage users, groups and apps." : "Aquesta aplicació habilita un conjunt d'API que els sistemes externs poden utilitzar per a administrar usuaris, grups i aplicacions.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query user\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin users\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Aquesta aplicació habilita un conjunt d'API que els sistemes externs poden utilitzar per a crear, editar, suprimir i consultar atributs\n\t\td'usuari, consultar, definir i suprimir grups, definir la quota i consultar l'emmagatzematge total en ús al Nextcloud. Els usuaris administradors de grup\n\t\ttambé poden enviar consultes al Nextcloud i realitzar les mateixes funcions que un administrador per als grups que administren. L'API també permet a\n\t\tun administrador consultar les aplicacions actives del Nextcloud, la informació de l'aplicació i habilitar o inhabilitar una aplicació de forma remota.\n\t\tUn cop habilitada l'aplicació, es poden utilitzar sol·licituds HTTP mitjançant una capçalera d'autenticació bàsica per a realitzar qualsevol de les funcions\n\t\tindicades anteriorment. Podeu trobar més informació en la documentació de l'API d'aprovisionament, incloent-hi exemples\n\t\tde trucades i respostes del servidor."
},
"nplurals=2; plural=(n != 1);");
