OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "ตรวจพบการเข้าสู่ระบบจากสถานที่ใหม่",
    "New login detected" : "ตรวจพบการเข้าสู่ระบบใหม่"
},
"nplurals=1; plural=0;");
