OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "வணக்கம் %s",
    "Hello %s," : "வணக்கம் %s,",
    "seconds ago" : "செக்கன்களுக்கு முன்",
    "Your settings have been updated." : "உங்களின் அமைப்புகள் சேமிக்கப்பட்டன"
},
"nplurals=2; plural=(n != 1);");
