<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'Base32\\Base32' => $vendorDir . '/christian-riesen/base32/src/Base32.php',
    'Base32\\Base32Hex' => $vendorDir . '/christian-riesen/base32/src/Base32Hex.php',
    'EasyTOTP\\Factory' => $vendorDir . '/rullzer/easytotp/src/Factory.php',
    'EasyTOTP\\TOTP' => $vendorDir . '/rullzer/easytotp/src/TOTP.php',
    'EasyTOTP\\TOTPInterface' => $vendorDir . '/rullzer/easytotp/src/TOTPInterface.php',
    'EasyTOTP\\TOTPInvalidResult' => $vendorDir . '/rullzer/easytotp/src/TOTPInvalidResult.php',
    'EasyTOTP\\TOTPInvalidResultInterface' => $vendorDir . '/rullzer/easytotp/src/TOTPInvalidResultInterface.php',
    'EasyTOTP\\TOTPResultInterface' => $vendorDir . '/rullzer/easytotp/src/TOTPResultInterface.php',
    'EasyTOTP\\TOTPValidResult' => $vendorDir . '/rullzer/easytotp/src/TOTPValidResult.php',
    'EasyTOTP\\TOTPValidResultInterface' => $vendorDir . '/rullzer/easytotp/src/TOTPValidResultInterface.php',
    'EasyTOTP\\TimeService' => $vendorDir . '/rullzer/easytotp/src/TimeService.php',
);
