(self.webpackChunk_nextcloud_text=self.webpackChunk_nextcloud_text||[]).push([["highlight/properties-js-js","highlight/properties"],{17546:e=>{e.exports=function(e){const n="[ \\t\\f]*",t=n+"[:=]"+n,s="[ \\t\\f]+",i="([^\\\\:= \\t\\f\\n]|\\\\.)+",a={end:"("+t+"|"+s+")",relevance:0,starts:{className:"string",end:/$/,relevance:0,contains:[{begin:"\\\\\\\\"},{begin:"\\\\\\n"}]}};return{name:".properties",disableAutodetect:!0,case_insensitive:!0,illegal:/\S/,contains:[e.COMMENT("^\\s*[!#]","$"),{returnBegin:!0,variants:[{begin:i+t},{begin:i+s}],contains:[{className:"attr",begin:i,endsParent:!0}],starts:a},{className:"attr",begin:i+n+"$"}]}}},19862:(e,n,t)=>{!function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/properties" instead of "highlight.js/lib/languages/properties.js"'))}(),e.exports=t(17546)}}]);
//# sourceMappingURL=properties-js-js.js.map?v=bd8ed6d2813076bf60c0