OC.L10N.register(
    "settings",
    {
    "Private" : "Prevez",
    "Local" : "Diabarzh",
    "Federated" : "Kevredet",
    "Only synchronize to trusted servers" : "Kempredañ da servijourioù fiziet nemetken",
    "Synchronize to trusted servers and the global and public address book" : "Kempreda da servijourioù fiziet ha d'al levr chom-lerc'hioù oublik a hollek",
    "Verify" : "Gwiriañ",
    "Verifying …" : "O wiriañ...",
    "Unable to change password" : "N'eo ket  bet posupl cheñch ar ger-tremen",
    "Very weak password" : "Ger-tremen skanv kenan",
    "Weak password" : "Ger-tremen skanv",
    "So-so password" : "Ger-tremen skañvig",
    "Good password" : "Ger-tremen mat",
    "Strong password" : "Ger-tremen kreñv",
    "Groups" : "Strolladoù",
    "Group list is empty" : "Listenn strollat goulo",
    "Unable to retrieve the group list" : "Dibosupl eo adtapout al listenn strollad",
    "{actor} added you to group {group}" : "{actor} en deus ouzhpennet ac'hnnoc'h er strollad {group}",
    "You added {user} to group {group}" : "Ouzhpennet o peus {user} et strollad {group}",
    "{actor} added {user} to group {group}" : "{actor] En deus ouzhpennet {user} d'ar strollad {group}",
    "An administrator added you to group {group}" : "Ar merour en deus ouzhpennet ac'hannoc'h d'ar strollad {group}",
    "An administrator added {user} to group {group}" : "Ar merour en deus ouzhpennet {user} d'ar strollad {group}",
    "{actor} removed you from group {group}" : "{actor} a zo bet lamet eus ar strollad {group}",
    "You removed {user} from group {group}" : "Lammet o peus {user} eus ar strollad {group}",
    "{actor} removed {user} from group {group}" : "{actor} en deus lmmet {user} eus ar strollad {group}",
    "An administrator removed you from group {group}" : "Ar merour en deus lammet ac'hanoc'h eus ar strollad {group}",
    "An administrator removed {user} from group {group}" : "Ar merour en deus lamet {user} eus ar strollad {group}",
    "Your <strong>group memberships</strong> were modified" : "Ho <strong>gwirioù strollad</strong> a zo bet cheñchet",
    "{actor} changed your password" : "{actor} en deus chechet o ger-tremen",
    "You changed your password" : "Cheñchet o peus o ger-tremen",
    "Your password was reset by an administrator" : "Ho ger-tremen a zo bet cheñchet gant ar merour",
    "Your password was reset" : "Cheñchet eo bet o ger-tremen",
    "{actor} changed your email address" : "{actor} en deus cheñchet o chom-lec'h postel",
    "You changed your email address" : "Cheñchet o peus ho chom-lec'h postel",
    "Your email address was changed by an administrator" : "Cheñchet eo bet ho chom-lec'h postel gant an merour",
    "You deleted app password \"{token}\"" : "Lamet ho peus ar ger-tremen meziant \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Adanvet ho peus ar ger-tremen meziant eus \"{token}\" da \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Aotreañ a rit ar restroù sistem da tizañ ar ger-tremen meziant \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Difennet o peus d'ar restroù sistem da dizañ ar ger-tremen meziant \"{tiken}\"",
    "Security" : "Surentez",
    "You successfully logged in using two-factor authentication (%1$s)" : "Deuet oc'h tre mat en ur implijout un dilesa daou-elfenn (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "C'hwitet eo ar mont tre gant un dilesa daou elfenn (%1$s)",
    "Remote wipe was started on %1$s" : "Groget eo al lemel pall da %1$s",
    "Remote wipe has finished on %1$s" : "Echuet eo bet al lemel pell da %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ho <strong>ger-tremen</strong> pe <strong>postel</strong> a zo bet cheñchet",
    "Apps" : "Meziant",
    "Wrong password" : "Ger-tremen fall",
    "Saved" : "Enrollet",
    "No user supplied" : "Implijour roet ebet",
    "Authentication error" : "Fazi dilesa",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Mar-plij, roit ur ger-tremen adtapout d'ar merour; mod all e vo kollet roadennoù an implijer.",
    "Wrong admin recovery password. Please check the password and try again." : "Ger-tremen adtapout ar merour fall. Gwiriit ar ger-tremen ha klaskit en dro.",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL a zo o implij ur stumm mkozh eus %1$s (%2$s). Adnevesait ho sistem ober pe ne labouro ket mat perzhioù 'zo evel %3$s.",
    "Administrator documentation" : "Dielvadur ar merour",
    "User documentation" : "Dielvadur an implijer",
    "Invalid SMTP password." : "Ger-tremen SMTP fall.",
    "Email setting test" : "Amprouiñ stumm ar postel",
    "Well done, %s!" : "Gouc'hemenoù, %s !",
    "If you received this email, the email configuration seems to be correct." : "Ma eo bet resevet ar postel ganeoc'h, stummadur ar bostel a seblant bezañ bet graet mat.",
    "Email could not be sent. Check your mail server log" : "N'eo ket posupl kas ar postel. Gwiriit kazetenn servijour evit ar bostel.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ur gudenn a zo bet en ur kas ar bostel. Adstummit o stumm (Fazi : %s)",
    "Users" : "Implijer",
    "Invalid mail address" : "Chom-lec'h postel fall",
    "Settings saved" : "Stummoù enrollet",
    "Unable to change full name" : "Dibosupl cheñch tout an anv",
    "Unable to change email address" : "Dibosuple cheñch ar chom-lec'h postel",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Evit gwiriañ ho c'hont Twitter, kasit an tweet mañ war Twitter (bezit sur kas anezhañ hep teriñ al linenn) :",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Evit wiriañ ho Website, gwarnit an traoù goude en o gwrizienn-web e  '.well-known/CloudIdVerificationCode.txt' (bezit sur eo tout an destenn war ul linenn nemetken) :",
    "%1$s changed your password on %2$s." : "%1$s en deus cheñchet o ger-tremen war %2$s.",
    "Your password on %s was changed." : "Cheñchet eo bet o ger tremen war %s.",
    "Your password on %s was reset by an administrator." : "Cheñchet eo bet ho ger-tremen gant an merour war %s.",
    "Your password on %s was reset." : "Cheñchet eo bet o ger-tremen war %s.",
    "Password for %1$s changed on %2$s" : "O ger-tremen evit %1$s a zo bet cheñchet war %2$s",
    "Password changed for %s" : "Ger-tremen evit %s",
    "If you did not request this, please contact an administrator." : "Ma n'ho peus ket goullenet se, galvit o merour.",
    "Your email address on %s was changed." : "Cheñchet eo bet ho chom-lec'h postel war %s.",
    "Your email address on %s was changed by an administrator." : "Ho chom-lec'h postel war %s a zo bet cheñchet gant ar merour.",
    "Email address for %1$s changed on %2$s" : "Ar chom-lec'h postel evit %1$s a zo bet cheñchet war %2$s",
    "Email address changed for %s" : "Chom-lec'h postel cheñchet evit %s",
    "The new email address is %s" : "Ar chom-lec'h postel nevez a zo %s",
    "Your %s account was created" : "O c'hont %s a zo bet krouet",
    "Welcome aboard" : "Donemat e bourz",
    "Welcome aboard %s" : "Donemat e bourz %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Donemat d'ho c'hont %s, posupl eo deoc'h ouzhpennañ, gwarezi ha rannañ o roadennoù.",
    "Your username is: %s" : "Ho anv implijer a zo : %s",
    "Set your password" : "Lakaat ho ger-tremen",
    "Go to %s" : "Mont da %s",
    "Install Client" : "Stalia ar c'hliant",
    "Logged in user must be a subadmin" : "An trement e implijer a zo ret bezañ un iz-merour",
    "Settings" : "Arventennoù",
    "Personal" : "Personel",
    "Administration" : "Merouriez",
    "Additional settings" : "Stummoù ouzhpenn",
    "Groupware" : "Labour a stroll",
    "Overview" : "Taol-lagad",
    "Basic settings" : "Stummoù diazez",
    "Sharing" : "Rannan",
    "Calendar" : "Deiziataer",
    "Personal info" : "Titouroù personel",
    "Mobile & desktop" : "Hezouk ha burev",
    "Email server" : "Servijour postel",
    "Security & setup warnings" : "Kemmenadennoù suretez ha stumm",
    "Background jobs" : "Labour diadreñv",
    "Unlimited" : "Didermenet",
    "Verifying" : "O gwiriañ",
    "Disabled" : "Disaotreañ",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Stumm ar sifrañ kostez ar servijour kozh a zo aotreet. Aliet eo hen disaotreañ.",
    "Supported" : "Douget",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù trolinenn ha stummoù an etrefas.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne seblant ket bezañ staliet mat evit goulenn d'ar sistem argemennoù endro. An amprouenn gant getenv(\"PATH\") a ro ur respont goullo.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Aotreet a zo bet ar stumm lenn-nemetken. Ampechiñ a ra cheñch stummoù dre an etrefas-web. Ouzhpenn-se, ar restr en deus ezhomm bezañ adlakaet da  vezañ embannapl dre dorn evit pep adneveziñ.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ho roadennoù-diaz ne droont ket gant al live \"READ COMMITTED\". Kudennoù a zo posupl kaout pa vez graet meur a ober war an dro.",
    "Nextcloud settings" : "Stummoù Nextcloud",
    "None" : "Hini ebet",
    "Allow apps to use the Share API" : "Aotreañ ar meziant d'a implijout Share API",
    "Allow resharing" : "Aotrea an adrannañ",
    "Allow sharing with groups" : "Aotreañ ar rannan gant ur strollad ",
    "Restrict users to only share with users in their groups" : "Redia an implijourien da ranna nemet gant an implijourien en o strolladoù",
    "Allow public uploads" : "Aotreañ ar bellkas publik",
    "Always ask for a password" : "Goulenn ar ger-tremen bewech.",
    "Enforce password protection" : "Rediañ ar gwarez dre ger-tremen",
    "Exclude groups from sharing" : "Lemel ar strolladoù eus ar rannañ",
    "These groups will still be able to receive shares, but not to initiate them." : "Posupl vo d'ar strolad resev rannadennoù, mes ne vo ket posuple d'eo o krouiñ.",
    "Set default expiration date for shares" : "Lakaat un deizat termen dre ziouer evit ar rannañ",
    "Enforce expiration date" : "Rediañ an deiziat diamzerañ",
    "This text will be shown on the public link upload page when the file list is hidden." : "Diskouezet e vo an destenn war ar bajenn publik palkass liammoù pa eo kouachet ar roll restroù.",
    "Default share permissions" : "Aotreoù rannañ dre ziouer",
    "Two-Factor Authentication" : "Dilesa daou-elfenn",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "An dilesa daou-elfenn a zo posupl rediañ evit tout an implijourieñ ha strolladoù 'zo. Ma n'ho deus get stummet ar goulenner deao-elfenn, ne vo ket posupl dezho mon-tre er sistem.",
    "Enforce two-factor authentication" : "Reddiañ an dilesa daou-elfenn",
    "Limit to groups" : "Nemet d'ar strolladoù",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Posupl eo rediañ an dilesa daou-elfenn da strolladoù 'zo nemetken.",
    "Two-factor authentication is enforced for all members of the following groups." : "Rediet eo an dilesa daou-elfenn da izili ar strolladoù didan.",
    "Enforced groups" : "Rediañ strollad",
    "Two-factor authentication is not enforced for members of the following groups." : "N'eo ket rediet an dilesa daoi-elfenn evit izili ar strolladoù dindan.",
    "Excluded groups" : "Strolladoù argaset",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Pa vez choazet/argaset strolladoù, implijoet a vez gantez ar vezoniezh da heul evit gouzout ma eo bet rediet un dilesa daou-elfenn d'un implijer :  m'a n'eo ket bet choazet strollad ebet, an dilesa daou-elfenn a zo aotreet evit tout ar strolladoù estreget ar re argaset. M'az eo bet choazet strolladoù, an dilesa daou-elfenn a zo aotreet evito. M'az eo un implijer en ur strollad choazt hag un argaset, an hini choazet zo lakaet war-raok hag an dilesa daou-elfenn a vez rediet.",
    "Save changes" : "Enrollañ ar cheñchamantoù",
    "All" : "Pep tra",
    "Limit app usage to groups" : "Lakaat ar meziant da veza implijet gant ar strolladoù nemetken",
    "No results" : "Disoc'h ebet",
    "Update to {version}" : "Oc'h adneveziñ da {version}",
    "Remove" : "Lemel",
    "Disable" : "Disaotreañ",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "N'en deus ket ar meziant ur stumm izelañ evit Nextcloud. Ur fazi a vo en dazont.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ar meziant n'en deus ket ur stumm huela eus Nextcloud merked. Ur fazi vo en dazont.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "N'eo ket posupl staliañ ar meziant peogwir n'eo ket bet graet war dro an amzalc'hioù :",
    "View in store" : "Gwellet er stall",
    "Visit website" : "Mont war al lec'hienn",
    "Report a bug" : "Dugas ur gudenn",
    "Admin documentation" : "Dielvadur ar merour",
    "Developer documentation" : "Diellvadur an digeler",
    "This app is supported via your current Nextcloud subscription." : "Ar meziant-mañ a vez douget dre ho kommanant Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Meziantoù perzhiet a vez digeliet gant ha e-vbarzh ar gummuniezh. Perzhioù penna a vez roet gante ha prest int da krouiñ reoù all.",
    "Featured" : "Perzhiet",
    "Update to {update}" : "Adnevesiñ da {update}",
    "Icon" : "Skeudennig",
    "Name" : "Anv",
    "Version" : "Stumm",
    "Actions" : "Oberoù",
    "Results from other categories" : "Disoc'hoù evit rummadoù all",
    "No apps found for your version" : "Meziant ebet kavet evit ar stumm",
    "Disable all" : "Difenn pep tra",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ"],
    "Marked for remote wipe" : "Market evit bezañ lamet a bell",
    "Device settings" : "Stummoù ardivink",
    "Allow filesystem access" : "Aotreañ an tremen d'ar restroù sistem",
    "Rename" : "Adenvel",
    "Revoke" : "Digargañ",
    "Wipe device" : "Lemel an dra",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome evit Android",
    "iPhone" : "iPhone",
    "iPad" : "Pad",
    "Sync client - {os}" : "Kempren kliant - {os}",
    "This session" : "An estez-mañ",
    "Device" : "Ardivink",
    "Last activity" : "Oberenn divezhañ",
    "Devices & sessions" : "Ardivinkoù ha estezioù",
    "Web, desktop and mobile clients currently logged in to your account." : "Ar c'hliant Web, burev ha hezouk a zo kenstaget en ho c'hont.",
    "Do you really want to wipe your data from this device?" : "C'hoant o peus lemel ar roadennoù diouzh o ardivink ?",
    "Confirm wipe" : "Gwiriañ al lemel",
    "Error while creating device token" : "Ur fazi a zo bet en ur groiñ jedour an ardivink",
    "Error while updating device token scope" : "Ur fazi a zo bet en ur adnevesiñ pellder ar jedouer",
    "Error while updating device token name" : "Ur fazi a zo bet en ur adnevesiñ anv jedouer an ardivink",
    "Error while deleting the token" : "Ur fazi zo bet en ur lemmek ar jedouer",
    "Error while wiping the device with the token" : "Ur fazi a zo bet en ul lemel an ardivink gant ar jedouer",
    "App name" : "Anv meziant",
    "Create new app password" : "Krouiñ ur ger-tremen meziant nevez",
    "Use the credentials below to configure your app or device." : "Implij kretaatoù dindan evit stummañ o meziant pe ardivink.",
    "For security reasons this password will only be shown once." : "Ne vo diskwellet ar ger-tremen ur wech nemetken abalamour d'ar surentez.",
    "Username" : "anv implijer",
    "Password" : "Ger-tremen",
    "Done" : "Graet",
    "Show QR code for mobile apps" : "Diskouez ar c'hod QR evit ar meziant hezouk",
    "Copied!" : "Eilet eo !",
    "Copy" : "Eilañ",
    "Could not copy app password. Please copy it manually." : "N'eo ket posupl eilan ar ger-tremen meziant. Eilit anezhan gant an dorn.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Implijit sevichoù ar sistem cron evit gervel restr cron.php pep 5 munutenn.",
    "Enable" : "Aotreañ",
    "Server-side encryption" : "Sifradur ar servijour-goztez",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Sifradur kostez-srvijour aotre ar sifrañ restroù a vez pellkarget war ar servijour. Bevennet eo an ober, evel ur mont en dro gorekoc'h, n'a implijit se nemet m'az o peus ezhomm neuze.",
    "Enable server-side encryption" : "Aotrea sifradur kostez-servijour",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ur wech lakaet ar sifradur, pep restr pellkarget war ar servijour diouzh al lec'h mañ a vo sifret war ar servijour. Ne vo posupl lemel ar sifrañ diwezatoc'h ma zoug ar vodul sifrañ ar geweriuster, ha pep amplegad a-raok (sellit ouzh penaos lakaat un alrc'hwez adtapout).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Ar sifradur nemetken na warant ket surentez ar sistem. Sellit ouz an dielvadur evit muioc'h a ditouroù diwar benn penaos e dro, sifradur ar meziantoù, hag ar an darvoudoù implij douget.",
    "Be aware that encryption always increases the file size." : "Gouzit eo vez kemeret muioc'h a blas gant ur restr sifret.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Mat eo kaout ur vackup reoliek eus o roadennoù, ha e bezit sur ober ur vackup eus an alrv'hwez sifrañ gant o roadennoù sifret.",
    "This is the final warning: Do you really want to enable encryption?" : "Kemenadenn diwall divezhañ : Sur oc'h aotreañ ar sifrañ ?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul sifrañ karget ebet, aotreit ar vodul sifrañ er roll meziantoù.",
    "Select default encryption module:" : "Choaz ur modul sifrañ dre ziouer :",
    "Cancel" : "Arrest",
    "Confirm" : "Kadarnañ",
    "Submit" : "Kinnig",
    "Remove group" : "Lemel strollad",
    "Current password" : "Ger-tremen hiziv",
    "New password" : "Ger-tremen nevez",
    "Change password" : "Cheñch ger-tremen",
    "Picture provided by original account" : "Skeudenn roet gant ar c'hont orin",
    "Details" : "Munudoù",
    "You are a member of the following groups:" : "Er strolladoù-mañ emaoc'h",
    "No email address set" : "Chom-lec'h postel ebet lakaet",
    "Help translate" : "Sikour treiñ",
    "No language set" : "Yezh ebet lakaet",
    "Your phone number" : "O niverenn pelgomzer",
    "Add" : "Ouzhpennañ",
    "Create" : "Krouiñ",
    "Change" : "Cheñch",
    "Delete" : "Dilemel",
    "Reshare" : "Adrannañ",
    "Default language" : "Yezh dre ziouer",
    "Common languages" : "Yezh boutiñ",
    "Password change is disabled because the master key is disabled" : "N'eo ket aotreet cheñch ger-tremen peogwir n'eo ket aotreet an alc'hwez meur",
    "New user" : "Implijer nevez",
    "Display name" : "Anv ardivink",
    "Email" : "Postel",
    "Quota" : "Quota",
    "Language" : "Yezh",
    "Avatar" : "Avatar",
    "Group admin for" : "Strollad merour evit",
    "User backend" : "Backen implijer",
    "Storage location" : "Lec'h berniañ",
    "Last login" : "Mont-tre divezhañ",
    "You do not have permissions to see the details of this user" : "N'oc'h ket aotreet da gwellet munudoù an implijer",
    "Set user as admin for" : "Lakaat an implijer da merour evit",
    "Select user quota" : "Choaz quota an implijer",
    "{size} used" : "{size} implijet",
    "Delete user" : "Lemel implijer",
    "Wipe all devices" : "Lemel pep ardivink",
    "Disable user" : "Disaotreañ an implijour",
    "Enable user" : "Aotreañ an implijour",
    "Resend welcome email" : "Adkas ar postel degemer mat",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Ma peus kollet o ardivink pe kuitaet ar strollad, posupl e vefe lemet a pell roadennoù Nextcloud eus tout o ardivinkoù liamet gant {userid}. Ne gerzh nemet ma eo kenstaget an ardivinkoù gant internet.",
    "Remote wipe of devices" : "Lemel a bell an ardivink",
    "Wipe {userid}'s devices" : "Lemel ardivink {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Lemet eo bet penn-da-benn kont {userid} gant pep restr personnel, roadennoù meziant, hag-all-hag-all.",
    "Account deletion" : "Lemel ar c'hont",
    "Delete {userid}'s account" : "Lemel kont {userid}",
    "Welcome mail sent!" : "Postel degemer kaset !",
    "Toggle user actions menu" : "Diskwell/koachañ ar roll ober",
    "Edit" : "Cheñch",
    "Show user backend" : "Diskouez backend an implijer",
    "Show storage path" : "Diskouez an hent klenkañ",
    "Show last login" : "Diskouez ar c'hennask diwezhañ",
    "Send email" : "Kas postel",
    "Default quota" : "Quota dre ziouer",
    "Select default quota" : "Choaz ar c'hota dre ziouer",
    "Passwordless authentication requires a secure connection." : "Ret eo kaout ur c'henstagadur sur evit un dilesa di-ger-tremen.",
    "Add WebAuthn device" : "Ouzhpenn ardivink WebAuthn",
    "Please authorize your WebAuthn device." : "Aotreit o ardivink WebAuthn.",
    "Name your device" : "Anvit o ardivink",
    "Adding your device …" : "Ouehpennit ho ardivink ...",
    "Server error while trying to add WebAuthn device" : "Ur fazi servijour a zo bet pa oa ouzhpennet an ardivink WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Ur fazi servijour a zo bet pa oa glotaet an ardivink WebAuthn",
    "Unnamed device" : "Ardivink hep anv",
    "Passwordless Authentication" : "Dilesa hep ger-tremen",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Lakaat o c'hont da implij an dilesa hap ger-tremen en ur heuliañ ar standart FIDO2.",
    "No devices configured." : "Ardivink stummet ebet.",
    "The following devices are configured for your account:" : "Stummet eo bet an ardivinkoù ma d'ho c'hont.",
    "Your browser does not support WebAuthn." : "Ne vez ket douget WebAuthn gant o furcher.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Evel ar merour eo posupl deoc'h stumañ pizh penaos e vez rannet. Sellit ouz an diellvadur evit muioc'h a ditouroù.",
    "Your apps" : "Ho meziantoù",
    "{license}-licensed" : "{license}-aotre",
    "by {author}\n{license}" : "great gant {author}\n{license}",
    "Admins" : "Merourien",
    "Disabled users" : "Disaotreañ implijer",
    "Sending…" : "O kas...",
    "Email sent" : "Postel kaset",
    "Location" : "Lec'hiadur",
    "Profile picture" : "Skeudenn trolinenn",
    "About" : "Diwar-benn",
    "Full name" : "Tout an anv",
    "Phone number" : "Niverenn pellgomzer",
    "Role" : "Roll",
    "Website" : "Lec'hien web",
    "Locale" : "Diabarzh",
    "Active apps" : "Meziantoù lakaet en dro",
    "Disabled apps" : "Meziantoù disaotreet",
    "Updates" : "Adnevesadennoù",
    "App bundles" : "Strolladoù meziant",
    "Featured apps" : "Meziant perzhiet",
    "Hide" : "Kouacha",
    "Download and enable" : "Pellgargañ ha aotreañ",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "N'eo ket ar meziant keverlec'h gant stumm Nextcloud. Ma kendalc'hit e o posupl deoc'h staliañ ar meziant. Taolit evez, ne labouro ket ar meziant evel ma zlefe.",
    "Never" : "James",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aotreet eo bet ar meziant mes ezomm e deus bezhan adnevesaet. Kaset a voc'h d'ar bajenn adneveziñ a benn 5 eilenn.",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Re a goulennoù a zo bet eus ar rouedat. Klaskit en dro diwezhatoc'h pe galvit ho merour m'az eus ur fazi.",
    "Documentation" : "Diellvadur",
    "Forum" : "Forum",
    "Login" : "Anv arveriad",
    "Open documentation" : "Digeriñ an dielvadur",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Pouezus eo stummañ ar servijour avit ma c'helfe kas posteloù, evit kemenadennoù pe posteloù evit cheñch ar ger-tremen.",
    "Send mode" : "Mod kas",
    "Encryption" : "Sifradur",
    "Sendmail mode" : "Mod kas-postel",
    "From address" : "Eus chom-lec'h",
    "Server address" : "Chom-lec'h ar servijour",
    "Port" : "Porzh",
    "Authentication required" : "Eus un dilesa ez eus ezhomp",
    "Credentials" : "Kretaatoù",
    "SMTP Username" : "Anv implijer SMTP",
    "SMTP Password" : "Ger-tremen SMTP",
    "Save" : "Enrollañ",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pouezus eo evit ar surentez hag ar mont en dro ho azgoulenn e vefe pep tra stummet mat. Evit sikour ac'hanoc'h e vez graet gwiradennoù otomatek. Sellit ouz an diellvadur liammet evit muioc'h a ditouroù.",
    "All checks passed." : "Pep gwiriekadenn tremenat.",
    "There are some errors regarding your setup." : "Fazioù 'zo liammet do staliadur.",
    "There are some warnings regarding your setup." : "Diwal a zo liammet d'o staliadur.",
    "Checking for system and security issues." : "O gwiriañ ne vefe kuden ebet gant ar sistem hag ar surentez.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Sellit ouzh <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">sturier ar staliañ ↗</a>, ha gwiriit ne vefe fazi pe diwal ebet er <a href=\"%2$s\">gazetenn</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Gwiriit surentez ho Nextcoud war <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hon skan surentez ↗</a>.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Digelet gant {communityopen}kummuniezh NExtcloud{linkclose}, ar {githubopen}c'hod orin{linkclose} a zo dindan aotre {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Liamm d'hon bajenn Facebook",
    "Follow us on Twitter" : "Heuliit ac'henomp war Twitter",
    "Follow us on Mastodon" : "Heuliit arc'hanomp war Mastodon",
    "Check out our blog" : "Sellit ouzh hon vlog",
    "Subscribe to our newsletter" : "Koumannantit d'hon kemenadennoù nevesadur",
    "Use a second factor besides your password to increase security for your account." : "Implijour un eil-elfenn d'ho ger-tremen a gwella urentez o c'hont.",
    "You created app password \"{token}\"" : "Ar ger-tremen meziant \"{token}\" o peus krouet",
    "Enable all" : "Aotreñ pep tra",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Ezhomm ez eus eus astennenn PHP POSIX evit al lakaat da dreiñ. Sellit ouzh {linkstart}diellvadur PHP{linkend} evit muioc'h a ditouroù.",
    "You are about to remove the group {group}. The users will NOT be deleted." : "O vont da lemel ar strollad {group} emaoc'h. An implijourienn NA VEZONT KET lemet.",
    "Please confirm the group removal " : "Gwiriit an dilemel",
    "png or jpg, max. 20 MB" : "png pe jpg, 20 MB d'ar muiañ",
    "Your email address" : "O chom-lec'h postel",
    "Add new password" : "Ouzhpennañ ur ger-tremen",
    "Add new email address" : "Ouzhpennañ ur chom-lec'h postel nevez",
    "Edit User" : "Embann implijer",
    "Will be autogenerated" : "A vo krouet en un doare otomatek",
    "Add a new user" : "Ouzhpennan un im^lijer",
    "No users in here" : "Implijour ebet amañ",
    "Enter group name" : "Lakat un anv strollad",
    "Add group" : "Ouzhpenn strollad",
    "Default quota:" : "Quota dre ziouer :",
    "Show Languages" : "Diskouez Yezhoù",
    "Send email to new user" : "Kes postel d'an implijer nevez",
    "Not saved" : "N'eo ket bet enrollet",
    "Twitter" : "Twitter",
    "Enable untested app" : "Aotreañ ar meziant disamprouet",
    "Plain" : "Sklaer",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Doare dilesa",
    "Set default expiration date" : "Lakaat un deizat termen dre ziouer"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
