<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  227202 => 'Niamey',
  227203 => 'Niamey',
  2272041 => 'Maradi',
  2272044 => 'Agadez',
  2272045 => 'Arlit',
  2272051 => 'Zinder',
  2272054 => 'Diffa',
  2272061 => 'Tahoua',
  2272064 => 'Konni',
  2272065 => 'Dosso',
  2272068 => 'Gaya',
  2272071 => 'Tillabéry',
  2272072 => 'Niamey',
  2272073 => 'Niamey',
  2272074 => 'Niamey',
  2272075 => 'Niamey',
  2272077 => 'Filingué',
  2272078 => 'Say',
);
