OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Ostatnio skontaktowano się",
    "Contacts Interaction" : "Interakcja kontaktów",
    "Manages interaction between users and contacts" : "Zarządza interakcją między użytkownikami i kontaktami",
    "Collect data about user and contacts interactions and provide an address book for the data" : "Zbieraj dane o interakcjach użytkowników i kontaktów oraz udostępniaj książkę adresową dla tych danych."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
