OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "Copiato!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "First run wizard" : "Procedura guidata di primo avvio",
    "Add your profile information! For example your email is needed to receive notifications." : "Aggiungi le tue informazioni di profilo! Ad esempio, il tuo indirizzo di posta è necessario per ricevere le notifiche.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Aggiungi le tue informazioni di profilo! Ad esempio, il tuo indirizzo di posta è necessario per ricevere le notifiche e per ripristinare la password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Aggiungi le informazioni del tuo profilo! Imposta un'immagine del profilo per una analisi veloce di tutte le funzionalità.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un nome completo per una analisi veloce delle funzionalità.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Aggiungi le informazioni del profilo! Imposta un'immagine del profilo per una analisi delle funzionalità.",
    "App recommendation: Nextcloud Calendar" : "Applicazione consigliata: Calendario di Nextcloud",
    "Schedule work & meetings, synced with all your devices." : "Pianificare lavoro e riunioni, sincronizzati con tutti i tuoi dispositivi.",
    "App recommendation: Nextcloud Contacts" : "Applicazione consigliata: Contatti di Nextcloud",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tieni i tuoi colleghi e i tuoi amici in un posto proteggendo le loro Informazioni personali.",
    "App recommendation: Nextcloud Mail" : "Applicazione consigliata: Posta di Nextcloud",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Applicazione di posta elettronica semplice e ben integrata con File, Contatti e Calendario.",
    "App recommendation: Tasks" : "Applicazione consigliata: Attività",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sincronizza le attività tra diversi dispositivi con il tuo Nextcloud e modificale in linea.",
    "App recommendation: Deck" : "Applicazione consigliata: Deck",
    "Kanban style organization for personal planning and team projects." : "Organizzazione in stile Kanban per la pianificazione personale e per i progetti di squadra.",
    "App recommendation: Forms" : "Applicazione consigliata: Forms",
    "Simple surveys and questionnaires, self-hosted" : "Sondaggi e questionari semplici, autonomi",
    "App recommendation: Recognize" : "Applicazione consigliata: Recognize",
    "Smart media tagging for Nextcloud" : "Tagging dei media intelligente per Nextcloud",
    "App recommendation: Group folders" : "Applicazione consigliata: Cartelle di gruppo",
    "Admin-configured folders shared by everyone in a group." : "Cartelle configurate dall'amministratore condivise da chiunque in un gruppo.",
    "About" : "Informazioni",
    "A welcome and introduction wizard for Nextcloud" : "Una procedura guidata di benvenuto e introduzione a Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Questa applicazione abilita una finestra a comparsa quando un utente accede per la prima volta Nextcloud. Questa finestra dà il benvenuto ai nuovi utenti di Nextcloud e contiene collegamenti al client desktop standard, all'applicazione Android e all'applicazione iOS. La finestra mostra anche un collegamento per accedere a Nextcloud tramite WebDAV. In qualsiasi momento, la procedura guidata di primo avvio può essere aperta tramite il collegamento \"Informazioni\" nel menu delle impostazioni.\nLa procedura guidata di primo avvio può essere personalizzata per rispondere a obiettivi specifici di design, o modificare collegamenti e messaggi. Creare un tema appropriato seguendo la documentazione di Temi, e cambiare l'aspetto della procedura guidata è semplice. Altre informazioni sono disponibili nella documentazione relativa alla procedura guidata di primo avvio così come nella documentazione relativa ai temi.",
    "Welcome to {cloudName}!" : "Benvenuto su {cloudName}!",
    "Privacy" : "Riservatezza",
    "Community" : "Comunità",
    "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s ti fornisce l'accesso ai tuoi file ovunque tu sia. I nostri client per desktop e mobile sono facili da utilizzare e sono disponibili gratuitamente per tutte le principali piattaforme.",
    "Desktop client" : "Client desktop",
    "Android app on Google Play Store" : "App Android su Google Play Store",
    "Android app on F-Droid" : "App Android su F-Droid",
    "iOS app" : "Applicazione iOS",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Imposta i client di sincronizzazione utilizzando una <a href=\"%s\">password di applicazione</a>. In tal modo, puoi assicurarti di essere in grado di revocare l'accesso nel caso in cui tu perda il dispositivo.",
    "Connect other apps to %s" : "Connetti altre applicazioni a %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Oltre alle applicazioni mobili e al client desktop, puoi connettere a %s qualsiasi altro software che supporti i protocolli WebDAV/CalDAV/CardDAV.",
    "Connect your calendar" : "Connetti il tuo calendario",
    "Connect your contacts" : "Connetti i tuoi contatti",
    "Access files via WebDAV" : "Accedi ai file tramite WebDAV",
    "Download macOS/iOS configuration profile" : "Scarica il profilo di configurazione per macOS/iOS",
    "Server address" : "Indirizzo del server",
    "Use this link to connect your apps and desktop client to this server:" : "Usa questo collegamento per connettere le tue applicazioni e il client desktop a questo server:",
    "Copy link" : "Copia collegamento",
    "Copy to clipboard" : "Copia negli appunti",
    "Start using {cloudName}" : "Inizia a utilizzare {cloudName}",
    "Extend your cloud" : "Estendi la tua nuvola",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Trovi più di 100 applicazioni nel negozio delle applicazioni per personalizzare il tuo cloud:",
    "Groupware apps like Calendar, Contacts, Mail" : "Applicazioni di groupware come Calendario, Contatti, Posta",
    "Communication with Nextcloud Talk" : "Comunicazione con Nextcloud Talk",
    "Collaboration apps for document editing" : "Applicazioni collaborative per la modifica dei documenti",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Funzionalità di sicurezza e autenticazione come l'autenticazione a due fattori, SSO e protezione da ransomware",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Molte altre come un lettore multimediale, un gestore delle password, un'applicazione kanban, un gestore degli scaricamenti o un editor Markdown",
    "Browse the App Store" : "Sfoglia il negozio delle applicazioni",
    "Stay in sync" : "Rimani sincronizzato",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud ti consente di accedere ai tuoi file ovunque tu sia.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "I nostri client per desktop e mobile sono disponibili per tutte le maggiori piattaforme a costo zero!",
    "Connect your desktop apps to %s" : "Connetti le tue applicazioni desktop a %s",
    "Get help" : "Ottieni aiuto",
    "Start contributing" : "Inizia a contribuire",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Vuoi ottenere un determinato miglioramento in Nextcloud? Hai trovato un problema? Vuoi aiutarci con le traduzioni, promuovere o documentare Nextcloud?",
    "Become part of the Community" : "Diventa parte della comunità",
    "Enterprise support" : "Supporto per le aziende",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "Se usi Nextcloud in un ambiente di importanza critica dove sicurezza e conformità sono fondamentali, hai sicuramente bisogno di Nextcloud Enterprise.",
    "Learn more about Nextcloud Enterprise" : "Maggiori informazioni su Nextcloud Enterprise",
    "Get more information" : "Ottieni altre informazioni",
    "The Nextcloud documentation for home users:" : "La documentazione di Nextcloud per gli utenti privati:",
    "User manual" : "Manuale utente",
    "Admin manual" : "Manuale di amministrazione",
    "Developer manual" : "Manuale dello sviluppatore",
    "You can also ask for help in our community support channels:" : "Puoi inoltre chiedere aiuto nei nostri canali di supporto della comunità:",
    "the Nextcloud forums" : "i forum di Nextcloud",
    "A safe home for all your data" : "Un posto sicuro per tutti i tuoi dati",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud mette i tuoi dati nelle tue mani, sotto il tuo controllo. Archivia i tuoi documenti, calendari, contatti e foto su un server nella tua azienda, a casa, presso uno dei tuoi fornitori o in un data center che conosci.",
    "Host your data and files where you decide" : "Ospita i tuoi dati e i file dove decidi",
    "Open standards and interoperability" : "Standard aperti e interoperabilità",
    "100%% open source & community-focused" : "100%% open source e focalizzato sulla comunità",
    "Learn more about %s" : "Scopri altro su %s",
    "This Nextcloud is on version %s" : "Questo Nextcloud è alla versione %s"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
