OC.L10N.register(
    "files_rightclick",
    {
    "Unselect all" : "Desmarcar todo.",
    "Share folder" : "Compartir carpeta",
    "Share file" : "Compartir archivo ",
    "Select" : "Seleccionar",
    "Copied !" : "¡Copiado! ",
    "Right click" : "Clic derecho ",
    "Right click menu for Nextcloud" : "Menú clic derecho para Nextcloud ",
    "This app allows users and developers to have a right click menu. Simply use the RightClick object to quickly create context menus. The Files app already shows the actions menu when right clicking on files and folders." : "Esta aplicación permite a los usuarios y desarrolladores tener un menú de clic derecho. Simplemente utiliza el objeto RightClick para crear rápidamente menús contextuales. La aplicación Files ya muestra el menú de acciones al hacer clic derecho en archivos y carpetas."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
