OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "សួស្ដី %s",
    "Hello %s," : "សួស្ដី %s,",
    "Notifications" : "ការ​ជូន​ដំណឹង",
    "seconds ago" : "វិនាទី​មុន",
    "in {path}" : "ក្នុង {path}",
    "Your settings have been updated." : "ការ​កំណត់​របស់​អ្នក​ត្រូវ​បាន​ធ្វើ​បច្ចុប្បន្នភាព។",
    "You need to set up your email address before you can receive notification emails." : "អ្នក​ចាំបាច់​ត្រូវតែដំឡើង​អាសយដ្ឋាន​អ៊ីមែលរបស់អ្នកមុនពេល​ដែលអ្នកអាចទទួលបានការជូន​ដំណឹង​ទៅកាន់​អ៊ីមែល ។"
},
"nplurals=1; plural=0;");
