OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "Visionneuse PDF",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Affichez vos documents PDF directement dans Nextcloud.\nEn bonus, cette application peut aussi afficher les fichiers Adobe Illustrator (.ai).\nBasé sur [pdf.js](https://mozilla.github.io/pdf.js/)",
    "File upload failed." : "Échec de l'envoi du fichier."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
