OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "おすすめファイル",
    "No recommendations yet" : "おすすめはまだありません",
    "Recently commented" : "最近追加されたコメント",
    "Recently edited" : "最近編集したもの",
    "Recently shared" : "最近共有したもの",
    "Recommendations" : "おすすめ",
    "Shows recommended files" : "おすすめファイルの表示",
    "Shows recommended files for quick access of files and folders with recent activity" : "最近の利用したファイルやフォルダーにすばやくアクセスできるようにおすすめファイルを表示します",
    "Path name {path}" : "パス名 {path}",
    "Show recommendations" : "おすすめを表示"
},
"nplurals=1; plural=0;");
