OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Ola %s",
    "Hello %s," : "Ola %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Nova notificación para %s","%nnotificacións  novas para %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Ten unha nova notificación para %s","Ten %n novas notificacións para %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Pode cambiar a frecuencia destes correos ou desactivalos nos <a href=\"%s\">axustes</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Pode cambiar a frecuencia destes correos ou desactivala nos axustes: %s",
    "Admin notifications" : "Notificacións de administración",
    "Notifications" : "Notificacións",
    "Push notifications - Fair use policy" : "Notificacións automáticas: directiva de uso xusto",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH patrocina unha pasarela de notificación automática de balde para usuarios privados. Para garantir un bo servizo, a pasarela limita o número de notificacións automáticas por servidor e acadouse o límite para este servidor. Para os usuarios empresariais, hai dispoñíbel unha pasarela máis escalábel.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Esta aplicación fornece unha infraestrutura e unha interface para a API de notificacións dispoñíbeis en Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Esta aplicación fornece unha infraestrutura e unha interface para a API de notificacións dispoñíbeis en Nextcloud.\n\t\tOutras aplicacións empregan a API para informar aos usuarios na interface web e sincronizar os clientes sobre varias cousas. Algúns exemplos son:\n\n📬 Compartición federada de ficheiros: Recibiu unha nova compartición remota\n\n📑 Comentarios: Outro usuario mencionouno a Vde. no comentario dun ficheiro\n\n🚢 Notificación de actualización: Actualización dispoñíbel para unha aplicación ou o propio Nexcloud\n\n📣 Centro de anuncios: Un administrador enviou un anuncio",
    "Failed to perform action" : "Produciuse un fallo ao realizar a acción",
    "Dismiss" : "Rexeitar",
    "Contact Nextcloud GmbH" : "Póñase en contacto con Nextcloud GmbH",
    "seconds ago" : "segundos atrás",
    "Failed to dismiss notification" : "Produciuse un erro ao rexeitar  a notificación",
    "in {path}" : "en {path}",
    "Dismiss all notifications" : "Rexeitar todas as notificacións",
    "Requesting browser permissions to show notifications" : "Solicitude de permisos do navegador para amosar as notificacións",
    "Push notifications might be unreliable" : "É posíbel que as notificacións automáticas non sexan fiábeis",
    "No notifications" : "Non hai notificacións",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH patrocina unha pasarela de notificación automática libre para usuarios privados. Para garantir un bo servizo, a pasarela limita o número de notificacións automáticas por servidor. Para os usuarios empresariais, hai dispoñíbel unha pasarela máis escalábel. Póñase en contacto con Nextcloud GmbH para obter máis información.",
    "Failed to dismiss all notifications" : "Produciuse un fallo ao rexeitar todas as notificacións",
    "Notifications defaults" : "Notificacións predeterminadas",
    "Configure the default notification settings for new users" : "Configure os axustes de notificación predeterminados para os novos usuarios",
    "Send email reminders about unhandled notifications after:" : "Enviar lembretes por correo sobre notificacións non xestionadas após:",
    "Play sound when a new notification arrives" : "Reproducir son cando chegue unha nova notificación",
    "Play sound when a call started (requires Nextcloud Talk)" : "Reproducir son cando se inicia unha chamada (precisa Nextcloud Talk)",
    "Never" : "Nunca",
    "1 hour" : "1 hora",
    "3 hours" : "3 horas",
    "1 day" : "1 día",
    "1 week" : "1 semana",
    "Your settings have been updated." : "Actualizaronse os axustes.",
    "An error occurred while updating your settings." : "Produciuse un erro ao actualizar os seus axustes.",
    "You need to set up your email address before you can receive notification emails." : "É necesario estabelecer o enderezo de correo para poder recibir correos de notificación."
},
"nplurals=2; plural=(n != 1);");
