OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Odporúčané súbory",
    "No recommendations yet" : "Zatiaľ žiadne odporúčania",
    "Recently commented" : "Nedávno komentované",
    "Recently edited" : "Nedávno upravené",
    "Recently shared" : "Nedávno sprístupnené",
    "Recommendations" : "Odporúčania",
    "Shows recommended files" : "Zobraziť odporúčané súbory",
    "Shows recommended files for quick access of files and folders with recent activity" : "Zobrazí odporúčané súbory pre rýchly prístup k súborom a priečinkom s ktorými ste nedávno niečo robili",
    "Show recommendations" : "Zobraziť odporúčania"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
