OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Rediañ stumm",
    "Whitelist IPs" : "Whitelist IPs",
    "Brute-force IP whitelist" : "Rediañ IP whitelist",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Evit lakaat ur strollad IP war ar whitelist adalek ar brute-force protection, lakit pere dindan. Pep IP war ar whitelist a hel klask gwiriekañ hep strizhadur. Blam d'ar surentez, gweloc'h eo lakaat war ar whitelist an neubetañ à implijourienn posuple, memes implijour ebet.",
    "Add new whitelist" : "Ouzhpennaén ur whitlist nevez",
    "Add" : "Ouzhpennañ",
    "Delete" : "Dilemel"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
