OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Osobní kanál aktivit pro %s",
    "Your feed URL is invalid" : "URL adresa kanálu není platná",
    "Activity feed for %1$s" : "Kanál aktivit pro %1$s",
    "Activity feed" : "Kanál aktivit",
    "Your settings have been updated." : "Vaše nastavení byla zaktualizována.",
    "Settings have been updated." : "Nastavení byla zaktualizována.",
    "Recent activity" : "Nedávná aktivita",
    "No activities" : "Žádné aktivity",
    "More activities" : "Další aktivity",
    "Daily activity summary for %s" : "Denní souhrn aktivit pro %s",
    "_and %n more _::_and %n more _" : ["a %n další","a %n další","a %n dalších","a %n další"],
    "All activities" : "Všechny aktivity",
    "By others" : "Ostatními",
    "By you" : "Vámi",
    "Activity at %s" : "Aktivita na %s",
    "Hello %s" : "Dobrý den %s",
    "Hello %s," : "Dobrý den %s,",
    "There was some activity at %s" : "Na %s došlo k následující aktivitě",
    "Mail" : "Pošta",
    "Push" : "Služba push",
    "Activity" : "Aktivita",
    "Notifications" : "Upozorňování",
    "This application enables people to view a log of activities about them, their files or other data." : "Tato aplikace lidem umožňuje prohlížet záznamy aktivit vztahujících se k nim, jejich souborům a dalším datům.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Tato aplikace lidem umožňuje zobrazit si akce související s jejich soubory a daty v Nextcloud.\n\t\tKaždá osoba si může vytvořit svá vlastní nastavení ohledně aktivit v osobních nastaveních,\n\t\tzvolit si, které aktivity posílat na mobilní telefony, posílat e-mailem\n\t\tnebo zda každé ráno posílat denní přehled.\n\t\tDalší informace jsou k dispozici v dokumentaci k Aktivitám.",
    "Activity notification configuration" : "Nastavení upozorňování ohledně aktivit",
    "Send email" : "Odeslat e-mail",
    "Send push notification" : "Odeslat push upozornění",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "You need to set up your email address before you can receive notification emails." : "Pokud chcete dostávat upozornění e-mailem, je nejprve třeba si v profilu zadat svou e-mailovou adresu.",
    "Send activity emails" : "Posílat e-maily ohledně aktivity",
    "As soon as possible" : "Co možná nejdříve",
    "Hourly" : "Každou hodinu",
    "Daily" : "Každý den",
    "Weekly" : "Každý týden",
    "You commented" : "Okomentovali jste",
    "Message deleted by author" : "Autor zprávu smazal",
    "Open {filename}" : "Otevřít {filename}",
    "in {path}" : "v {path}",
    "Home" : "Domů",
    "Your activities" : "Vaše aktivity",
    "Loading activities" : "Načítání aktivit",
    "This stream will show events like additions, changes & shares" : "Tento proud bude zobrazovat události jako přidání, změny a sdílení",
    "No activity yet" : "Zatím žádná aktivita",
    "Loading more activities" : "Načítání dalších aktivit",
    "No more activities." : "Žádné další aktivity",
    "Could not load activites" : "Nepodařilo se načíst aktivity",
    "Activity settings" : "Nastavení pro Aktivity",
    "Enable RSS feed" : "Zapnout RSS kanál",
    "RSS feed" : "RSS kanál",
    "Copy RSS feed link" : "Zkopírovat odkaz na RSS kanál",
    "Personal notification settings" : "Nastavení osobního upozorňování",
    "Could not enable RSS link" : "Nepodařilo se zapnout RSS odkaz",
    "RSS link copied to clipboard" : "Odkaz na RSS zkopírován do schránky",
    "Could not copy the RSS link, please copy manually:" : "Nepodařilo se zkopírovat odkaz na RSS – zkopírujte ručně:",
    "Unable to load the activity list" : "Nedaří se načíst seznam aktivit",
    "Notification" : "Upozornění",
    "Enable notification emails" : "Zapnout upozorňování e-mailem",
    "Choose for which activities you want to get an email or push notification." : "Zvolte pro které aktivity chcete dostávat upozornění e-mailem nebo přes službu push.",
    "Choose for which activities you want to get a push notification." : "Zvolte pro které aktivity chcete dostávat upozornění přes službu push.",
    "Daily activity summary" : "Denní souhrn aktivit",
    "Send daily activity summary in the morning" : "Každé ráno poslat souhrn denních aktivit",
    "Default settings" : "Výchozí nastavení",
    "Configure the default notification settings for new accounts." : "Nastavte výchozí volby ohledně upozorňování pro nově vytvářené účty.",
    "Unable to save the settings" : "Nastavení se nedaří uložit",
    "No more events to load" : "Žádné další události k načtení",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘+C.",
    "Press Ctrl-C to copy." : "Zkopírujete stisknutím Ctrl+C.",
    "{name} (invisible)" : "{name} (neviditelné)",
    "{name} (restricted)" : "{name} (omezeno)",
    "There are no events for this filter" : "Tato kritéria nesplňují žádné události",
    "This application enables users to view a log of activities about them or about files." : "Tato aplikace uživatelům umožňuje prohlížet záznamy aktivit vztahujících se k nim nebo s nimi souvisejícím souborům.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Tato aplikace umožní uživatelům sledovat události související s jejich soubory v Nextcloudu.\n\t\tJakmile je tato aplikace povolená, zobrazí se v menu nová ikona „Aktivita“\n\t\tPo kliknutí na ikonu se zobrazí nová stránka. Na této stránce uživatelé uvidí veškeré aktivity týkající se jejich souborů  – např. přidání a smazání, přesun, přejmenování, aktualizace, či sdílení.\n\t\tUživatel může nakonfigurovat aplikaci podle individuálních potřeb v osobním nastavení\n\t\tZde může zvolit, které jednotlivé události chce sledovat, zda chce sledovat vlastní aktivitu, nebo zda chce dostávat e-maily o zmíněných aktivitách\n\t\tVíce informací je dostupných v dokumentaci aplikace „Aktivita“",
    "Activities" : "Aktivity",
    "Configure the default notification settings for new users." : "Nastavte výchozí volby ohledně upozorňování pro nově vytvářené uživatele."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
