/*
 * Circles - Bring cloud-users closer together.
 *
 * This file is licensed under the Affero General Public License version 3 or
 * later. See the COPYING file.
 *
 * @author Maxence Lange <maxence@artificial-owl.com>
 * @copyright 2017
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#app-content-circlesfilter .select2-container {
	width: 30%;
	margin-left: 10px;
}

#app-content-circlesfilter .select2-choices {
	white-space: nowrap;
	text-overflow: ellipsis;
	background: #fff;
	color: #555;
	box-sizing: content-box;
	border-radius: 3px;
	border: 1px solid #ddd;
	padding: 0;
	min-height: auto;
}

.nav-icon-circlesfilter {
	background-image: url('../../img/circles.svg');
}

#app-sidebar .mainFileInfoView .tag-label {
	cursor: pointer;
	padding: 13px;
}

#app-sidebar .mainFileInfoView .icon-tag {
	opacity: .5;
	vertical-align: middle;
}
