<?php
// This file was auto-generated from sdk-root/src/data/resource-groups/2017-11-27/paginators-1.json
return [ 'pagination' => [ 'ListGroupResources' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => [ 'ResourceIdentifiers', 'Resources', ], ], 'ListGroups' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'GroupIdentifiers', ], 'SearchResources' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ResourceIdentifiers', ], ],];
