OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Addite al lista de servitores fiduciari.",
    "Server is already in the list of trusted servers." : "Servitor ja es in le lista de servitores fiduciari.",
    "No server to federate with found" : "Nulle servitor pro associar se per federation esseva trovate",
    "Could not add server" : "Impossibile adder le servitor",
    "Trusted servers" : "Servitores fiduciari",
    "Federation" : "Federation",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Le federation permitte te connecter con altere servitores fiduciari pro excambiar le directorio del usator. Per exemplo, iste attributo essera usate pro completar automaticamente usatores externe pro le compartimento federate.",
    "+ Add trusted server" : "+ Adder servitor fiduciari",
    "Trusted server" : "Servitor fiduciari",
    "Add" : "Adder"
},
"nplurals=2; plural=(n != 1);");
