OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "¡Copióse!",
    "Not supported!" : "¡Nun ye compatible!",
    "Press ⌘-C to copy." : "Primi ⌘-C pa copiar.",
    "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
    "First run wizard" : "Encontu pa la primer execución",
    "Welcome to {cloudName}!" : "¡Afáyate en {cloudName}!",
    "Privacy" : "Privacidá",
    "Desktop client" : "Veceru pa ordenadores",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Atopa más de 100 aplicaciones na tienda d'aplicaciones de Nextcloud pa personalizar la to nube:",
    "the Nextcloud forums" : "los foros de Nextcloud",
    "A safe home for all your data" : "Un llugar seguru pa los datos personales"
},
"nplurals=2; plural=(n != 1);");
