OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "هل ترغب في إضافة مُشاركة قصيّة remote ـ {name} من {owner}@{remote}؟",
    "Remote share" : "مُشاركة قصيّة remote",
    "Remote share password" : "كلمة مرور مُشاركة قصيّة remote",
    "Cancel" : "إلغاء",
    "Add remote share" : "إضافة مُشاركة قصيّة remote",
    "Invalid Federated Cloud ID" : "مُعرّف السحابة الاتحاديّة غير صحيح",
    "Server to server sharing is not enabled on this server" : "المُشاركة من خادوم إلى خادوم غير مُمكّنة على هذا الخادوم",
    "Couldn't establish a federated share." : "تعذّر تأسيس مُشاركة اتحاديّة.",
    "Couldn't establish a federated share, maybe the password was wrong." : "تعذّر تأسيس مُشاركة اتحاديّة. ربما بسبب كلمة مرور غير صحيحة",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "تمّ إرسال طلب مُشاركة اتحاديّة. سوف تصلك دعوة. رجاءً، تحقّق من إشعاراتك.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "تعذّر تأسيس مُشاركة اتحاديّة. يبدو أن إصدار خادوم نكست كلاود الذي طلبت الاتحاد معه قديمٌ ( ما قبل الإصدار 9). ",
    "It is not allowed to send federated group shares from this server." : "غيرُ مسموحٍ بإرسال مشاركات مجموعات اتحاديّة من هذا الخادوم.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "مُشاركة %1$s فشلت؛ بسبب أن هذا العنصر سبقت مُشاركته مع المُستخدِم %2$s ",
    "Not allowed to create a federated share with the same user" : "غيرُ مسموحٍ أن تُنشيء مُشاركةً اتحاديّةً مع نفس المُستخدِم",
    "Federated shares require read permissions" : "المُشاركات الاتحاديّة تتطلب إذونات قراءةٍ",
    "File is already shared with %s" : "سبقت مُشاركة الملف مع %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "المُشاركة %1$s فشلت؛ تعذّر إيجاد %2$s. يُمكن أن يكون هذ بسبب أن الخادوم لا يُمكن الوصول إليه حاليّاً أو أنه يستعمل شهادةً ذاتيّة التصديق self-signed certificate.",
    "Could not find share" : "تعذّر العثور على المُشاركة",
    "Federated sharing" : "مُشاركة اتحاديّة",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "أنت تلقّيتَ {share} كُمشاركة قصيّة من {user} (نيابةً عن {behalf})",
    "You received {share} as a remote share from {user}" : "أنت تلقّيتَ {share} كُمشاركة قصيّة من {user}  ",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Federated Cloud Sharing" : "المشاركة السحابية الموحّدة",
    "Sharing" : "المشاركة",
    "Federated file sharing" : "مُشاركة اتحاديّة لملف",
    "Provide federated file sharing across servers" : "توفير مُشاركة اتحاديّة للملفات عبر الخوادم",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "ضبط كيف يتشارك الأشخاص عبر الخوادم. و هذا يشمل المشاركات بين المستخدمين على هذا الخادوم و ما بين الخوادم الاتحاديّة كذلك.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "تمكين المستخدمين على هذا الخادوم من إرسال مُشاركاتٍ إلى خوادم أخرى ( هذا الخيار يُتيح أيضاً الوصول إلى المُشاركات العمومية عن طريق البروتوكول WebDAV )",
    "Allow users on this server to receive shares from other servers" : "تمكين المستخدمين على هذا الخادوم من استقبال مُشاركاتٍ من خوادم أخرى",
    "Allow users on this server to send shares to groups on other servers" : "تمكين المستخدمين على هذا الخادوم من إرسال مُشاركات إلى مجموعاتٍ على خوادم أخرى",
    "Allow users on this server to receive group shares from other servers" : "تمكين المستخدمين على هذا الخادوم من استقبال مُشاركاتٍ من مجموعاتٍ على خوادم أخرى",
    "Search global and public address book for users" : "البحث في سجلات العناوين العمومية public و الشاملة glabal عن مُستخدِمين",
    "Allow users to publish their data to a global and public address book" : "تمكين المستخدمين من نشر بياناتهم في سجلات العناوين الشاملة و العمومية",
    "Unable to update federated files sharing config" : "تعذر تحديث تهيئة مُشاركة الملفات الاتحادية",
    "Federated Cloud" : "سحابة اتحاديّة",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "يُمكنك المشاركة مع أي شخص يستخدم خادوم نكست كلاود أو خوادم وخدمات أخرى متوافقة مع بروتوكول Open Cloud Mesh (OCM)! فقط ضع مُعرّف السحابة الاتحاديّة Federated Cloud في مربع حوار المُشاركة؛ و الذي سيكون شكله على هذا النسق: person@cloud.example.com",
    "Your Federated Cloud ID:" : "مُعرّف سحابتك الاتحاديّة:",
    "Share it so your friends can share files with you:" : "شاركه مع أصدقائك بحيث يمكنهم مُشاركة الملفات معك:",
    "Facebook" : "فيسبوك",
    "Twitter" : "تويتر",
    "Diaspora" : "دياسبورا",
    "Add to your website" : "أضف إلى موقعك على الوب",
    "Share with me via Nextcloud" : "شاركه معي عبر النكست كلاود",
    "HTML Code:" : "كود HTML: ",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الاتّحاديّة Nextcloud Federated Cloud ID، أنظر {url} ",
    "Share with me through my #Nextcloud Federated Cloud ID" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الاتّحاديّة Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "تمّ نسخ مُعرّف السحابة إلى الحافظة",
    "Copy to clipboard" : "نسخ الرابط",
    "Clipboard is not available" : "الحافظة غير متوافرة",
    "Copied!" : "تم نسخه !",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "أنت تلقّيت \"%3$s\" كمُشاركةٍ قصيّةٍ من %4$s (%1$s) (نيابةً عن%5$s (%2$s))",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "أنت تلقّيت \"%3$s\" كمُشاركةٍ قصيّةٍ من %4$s (%1$s)",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "شارك معي من خلال # مُعرّف سحابة نكست كلاود الاتحاديّة Nextcloud Federated Cloud ID. أنظر %s"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
