<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'OCA\\Viewer\\AppInfo\\Application' => $baseDir . '/lib/AppInfo/Application.php',
    'OCA\\Viewer\\Event\\LoadViewer' => $baseDir . '/lib/Event/LoadViewer.php',
    'OCA\\Viewer\\Listener\\LoadViewerScript' => $baseDir . '/lib/Listener/LoadViewerScript.php',
);
