OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Kalender",
    "Calendar \"%s\"" : "Kalender \"%s\"",
    "Deck" : "Deck",
    "Files" : "Filer",
    "File \"%s\"" : "Fil \"%s\"",
    "Talk" : "Snak",
    "Talk conversation \"%s\"" : "Snak samtale \"%s\""
},
"nplurals=2; plural=(n != 1);");
