OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "Visor PDF",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Vista directa de Documentos PDF en tu Nextcloud. \nComo caracteristica adicional, esta app puede visualizar archivos de Adobe Illustrator (.ai)\nImpulsado por [pdf.js] (https://mozilla.github.io/pdf.js/)",
    "File upload failed." : "Carga de Archivo Fallida."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
