<?php
namespace Aws\MarketplaceEntitlementService;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Marketplace Entitlement Service** service.
 * @method \Aws\Result getEntitlements(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getEntitlementsAsync(array $args = [])
 */
class MarketplaceEntitlementServiceClient extends AwsClient {}
