OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Kalender",
    "Calendar \"%s\"" : "Kalender \"%s\"",
    "Deck" : "Stokk",
    "Files" : "Filer",
    "File \"%s\"" : "Fil \"%s\"",
    "Talk conversation" : "Talk-samtale",
    "Conversation with %s" : "Samtale med %s",
    "Talk" : "Samtale",
    "Related Resources" : "Relaterte ressurser",
    "Displays resources related to current item in right panel" : "Viser ressurser relatert til gjeldende element i høyre panel",
    "Displays resources related to current item in right panel." : "Viser ressurser relatert til gjeldende element i høyre panel."
},
"nplurals=2; plural=(n != 1);");
