OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Поштовање %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Ново обавештење за %s","%n нова обавештења за %s","%n нових обавештења за %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Имате ново обавештење за %s","Имате %n нова обавештења за %s","Имате %n нових обавештења за %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Можете да промените учесталост ових и-мејлова или да их потпуно искључите у <a href=\"%s\">подешавањима</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Можете да промените учесталост ових и-мејлова или да их потпуно искљуичите у подешавањима: %s",
    "Admin notifications" : "Администраторска обавештења",
    "Notifications" : "Обавештења",
    "Push notifications - Fair use policy" : "Брза обавештења - Полиса фер употребе",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH приватним корисницима спонзорише бесплатни портал брзих обавештења. Да би се обезбедио добар сервис, портал ограничава број брзих обавештења по серверу, а то ограничење је достигнуто на овом серверу. За корпоративне кориснике је доступан скалабилнији портал.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Ова апликација обезбеђује прочеље и позадину за обавештајни АПИ доступан у Некстклауду.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Ова апликација обезбеђује прочеље и позадину за обавештајни АПИ доступан у Некстклауду.\n\t\tАПИ користе друге апликације да обавесте корисника у веб окружењу и клијентима синхронизације о разним стварима. На пример:\n\n📬 Здружено дељење фајлова: неко је поделио нешто са вама\n\n📑 Коментари: неко вас је споменуо у коментару фајла\n\n🚢 Обавештења о ажурирању: доступна су ажурирања за неку апликацију или за сам Некстклауд\n\n📣 Центар за објаве: администратор је поставио објаву",
    "Failed to perform action" : "Не могу да извршим радњу",
    "Dismiss" : "Уклони",
    "Contact Nextcloud GmbH" : "Контактирајте Nextcloud GmbH",
    "seconds ago" : "пре неколико секунди",
    "Failed to dismiss notification" : "Не могу да уклоним обавештење",
    "in {path}" : "у {path}",
    "Dismiss all notifications" : "Уклони сва обавештења",
    "Requesting browser permissions to show notifications" : "Захтевам дозволе од веб читача за приказивање обавештења",
    "Push notifications might be unreliable" : "Брза обавештења могу бити непоуздана",
    "No notifications" : "Нема обавештења",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH приватним корисницима спонзорише бесплатни портал брзих обавештења. Да би се обезбедио добар сервис, портал ограничава број брзих обавештења по серверу. За корпоративне кориснике је доступан скалабилнији портал. За више информација контактирајте Nextcloud GmbH.",
    "Failed to dismiss all notifications" : "Не могу да уклоним сва обавештења",
    "Notifications defaults" : "Подразумевана подешавања обавештења",
    "Configure the default notification settings for new users" : "Конфигурисање подразумеваних подешавања обавештења за нове кориснике",
    "Send email reminders about unhandled notifications after:" : "Пошаљи и-мејл подсетнике у вези са необрађеним обавештењима након:",
    "Play sound when a new notification arrives" : "Пусти звук када стигне ново обавештење",
    "Play sound when a call started (requires Nextcloud Talk)" : "Пусти звук када започне позив (потребан је Некстклауд Разговор)",
    "Never" : "Никад",
    "1 hour" : "1 сат",
    "3 hours" : "3 сата",
    "1 day" : "1 дана",
    "1 week" : "1 недеље",
    "Your settings have been updated." : "Ваше поставке су ажуриране.",
    "An error occurred while updating your settings." : "Јавила се грешка током ажурирања ваших подешавања.",
    "You need to set up your email address before you can receive notification emails." : "Морате поставити адресу е-поште пре почетка пријема обавештења."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
