OC.L10N.register(
    "text",
    {
    "New text file" : "Naujas tekstinis failas",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko rašyti į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
    "Nextcloud Text" : "Nextcloud tekstas",
    "text document" : "tekstinį dokumentą",
    "{user} has mentioned you in the text document {node}" : "{user} paminėjo jus tekstiniame dokumente {node}",
    "Readme" : "Perskaityti",
    "Text" : "Tekstas",
    "📝 Collaborative document editing" : "📝 Dokumentų taisymas bendradarbiaujant",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 Dokumentų taisymas bendradarbiaujant!**\n\n- **📝 Rašymas susitelkus:** Jokio blaškymosi. Tik tas formatavimas, kurio jums reikia.\n- **🙋 Dirbkite kartu:** Bendrinkite ir bendradarbiaukite su draugais ir kolegomis, nepriklausomai nuo to, ar jie naudoja Nextcloud, ar ne!\n- **💾 Atvirasis formatas:** Failai yra įrašomi kaip [Markdown](https://en.wikipedia.org/wiki/Markdown), taigi, galite juos taisyti naudodami bet kurią kitą tekstų programėlę.\n- **✊ Stiprus pagrindas:** Mes naudojame [🐈 tiptap](https://tiptap.scrumpy.io), kuris yra pagrįstas [🦉 ProseMirror](https://prosemirror.net) – didelis jiems ačiū!",
    "Translate" : "Verskite",
    "Delete task" : "Ištrinti užduotį",
    "Use current version" : "Naudoti esamą versiją",
    "Use the saved version" : "Naudoti įrašytą versiją",
    "Document idle for {timeout} minutes, click to continue editing" : "Dokumentas {timeout} min. neveiklus, spustelėkite norėdami tęsti taisymą",
    "Reconnect" : "Jungtis iš naujo",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumentas pakeistas už redaktoriaus ribų. Pakeitimai negali būti pritaikyti.",
    "File could not be loaded. Please check your internet connection." : "Nepavyko įkelti failo. Patikrinkite savo interneto ryšį.",
    "This file is opened read-only as it is currently locked by {user}." : "Šis failas yra atvertas tik skaitymui, nes šiuo metu jį užrakino {user}.",
    "Enter your name so other people can see who is editing" : "Įveskite savo vardą, kad kiti žmonės matytų, kas redaguoja dokumentą",
    "Edit guest name" : "Taisyti svečio vardą",
    "Guest" : "Svečias",
    "Save guest name" : "Įrašyti svečio vardą",
    "Insert an attachment" : "Įterpti priedą",
    "guest" : "svečias",
    "Show author colors" : "Rodyti autoriaus spalvas",
    "Author colors are only shown until everyone has closed the document." : "Autoriaus spalvos yra rodomos tik tol, kol visi neužvers dokumento.",
    "Last saved" : "Paskutinį kartą įrašyta",
    "Offline" : "Atsijungęs",
    "Saving …" : "Įrašoma…",
    "Saved" : "Įrašyta",
    "Unsaved changes" : "Neįrašyti pakeitimai",
    "Formatting help" : "Formatavimo pagalba",
    "Style" : "Stilius",
    "Syntax" : "Sintaksė",
    "Keyboard shortcuts" : "Spartieji klavišai",
    "Shift" : "Lyg2",
    "Bold" : "Pusjuodis",
    "Bold text" : "Pusjuodis tekstas",
    "Ctrl" : "Vald",
    "Italic" : "Kursyvas",
    "Italicized text" : "Pasvirasis tekstas",
    "Strikethrough" : "Perbrauktas",
    "Mistaken text" : "Klaidingas tekstas",
    "Underline" : "Pabrauktas",
    "Underlined text" : "Pabrauktas tekstas",
    "Heading 1" : "Antraštė 1",
    "Heading level 1" : "Antraštės lygis 1",
    "Heading 6" : "Antraštė 6",
    "Heading level 6" : "Antraštės lygis 6",
    "Unordered list" : "Netvarkusis sąrašas",
    "An item" : "Punktas",
    "Ordered list" : "Tvarkusis sąrašas",
    "First item" : "Pirmasis punktas",
    "Checklist" : "Kontrolinis sąrašas",
    "To-Do item" : "Užduoties punktas",
    "Blockquote" : "Citata",
    "Quoted text" : "Cituojamas tekstas",
    "Code block" : "Kodo blokas",
    "Some code" : "Kažkoks kodas",
    "Insert from Files" : "Įterpti iš failų",
    "Remove link" : "Šalinti nuorodą",
    "Link to file or folder" : "Nuoroda į failą ar aplanką",
    "Link to website" : "Nuoroda į internetinę svetainę",
    "Update link" : "Atnaujinti nuorodą",
    "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodis"],
    "_%n char_::_%n chars_" : ["%n simbolis","%n simboliai","%n simbolių","%n simbolis"],
    "Editor actions" : "Redaktoriaus veiksmai",
    "Formatting menu bar" : "Formatavimo meniu juosta",
    "Remaining actions" : "Likę veiksmai",
    "Select language" : "Pasirinkite kalbą",
    "to" : "iki",
    "Replace" : "Pakeisti",
    "No emoji found" : "Nerasta jokių šypsenėlių",
    "Source code" : "Pradinis kodas",
    "Delete this attachment" : "Ištrinti šį priedą",
    "Delete this image" : "Ištrinti šį paveikslą",
    "Failed to load" : "Nepavyko įkelti",
    "Unsupported image type" : "Nepalaikomas paveikslo tipas",
    "Add row before" : "Pridėti eilutę aukščiau",
    "Add row after" : "Pridėti eilutę žemiau",
    "Delete this row" : "Ištrinti šią eilutę",
    "Add column before" : "Pridėti stulpelį kairėje",
    "Add column after" : "Pridėti stulpelį dešinėje",
    "Delete this column" : "Ištrinti šį stulpelį",
    "Delete this table" : "Ištrinti šią lentelę",
    "Undo" : "Atšaukti",
    "Redo" : "Grąžinti",
    "Headings" : "Antraštės",
    "Heading 2" : "Antraštė 2",
    "Heading 3" : "Antraštė 3",
    "Heading 4" : "Antraštė 4",
    "Heading 5" : "Antraštė 5",
    "To-Do list" : "Užduočių sąrašas",
    "Insert link" : "Įterpti nuorodą",
    "Callouts" : "Paaiškinimo išnašos",
    "Info" : "Informacija",
    "Success" : "Pavyko",
    "Warning" : "Įspėjimas",
    "Danger" : "Pavojus",
    "Table" : "Lentelė",
    "Insert emoji" : "Įterpti šypsenėlę",
    "Insert attachment" : "Įterpti priedą",
    "Command" : "Komanda",
    "Control" : "Valdoma",
    "Formatting" : "Formatavimas",
    "Add notes, lists or links …" : "Pridėkite užrašus, sąrašus ar nuorodas…",
    "Edit" : "Taisyti",
    "Document save status" : "Dokumento įrašymo būsena",
    "Update Link" : "Atnaujinti nuorodą",
    "Add Link" : "Pridėti nuorodą",
    "Link file" : "Susieti failą",
    "Remove Link" : "Šalinti nuorodą",
    "Select file to link to" : "Pasirinkite failą su kuriuo susieti",
    "Show rich workspaces" : "Rodyti raiškiąsias darbo sritis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
