OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Оголошення Nextcloud",
    "Nextcloud announcement" : "Оголошення Nextcloud",
    "Read more" : "Читати далі",
    "Disable announcements" : "Вимкнути оголошення",
    "(These announcements are only shown to administrators)" : "(Ці оголошення з'являються лише у адміністраторів)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Оголошення Nextcloud повідомляють останні новини Nextcloud у ваших сповіщеннях",
    "Shows the latest news of Nextcloud in your notifications." : "Показує останні новини Nextcloud у ваших сповіщеннях.",
    "These groups will be notified about the announcements." : "Ці групи будуть сповіщенні про оголошення."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
