OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Töölaud",
    "Dashboard app" : "Töölaua rakendus",
    "\"{title} icon\"" : "\"{title} ikoon\"",
    "Weather" : "Ilm",
    "Status" : "Staatus",
    "Good morning" : "Tere hommikust",
    "Good morning, {name}" : "Tere hommikust, {name}",
    "Good afternoon" : "Tere päevast",
    "Good afternoon, {name}" : "Tere päevast, {name}",
    "Good evening" : "Tere õhtust",
    "Good evening, {name}" : "Tere õhtust, {name}",
    "Hello" : "Tere",
    "Hello, {name}" : "Tere, {name}"
},
"nplurals=2; plural=(n != 1);");
