OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "Wedi'i gopïo!",
    "Not supported!" : "Heb ei gefnogi!",
    "Press ⌘-C to copy." : "Pwyswch ⌘-C i gopïo.",
    "Press Ctrl-C to copy." : "Pwyswch Ctrl-C i gopïo.",
    "System" : "System",
    "Monitoring" : "Monitro",
    "Size:" : "Maint:",
    "PHP" : "PHP",
    "Database" : "Cronfa ddata",
    "Type:" : "Math:",
    "Copy" : "Copïo"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
