OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Pendientes",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} borró el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted borró el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartido el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted ha compartido el calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha dejado de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted ha dejado de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir {el calendario calendar} con él mismo",
    "You shared calendar {calendar} with group {group}" : "Usted ha compartido el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted ha dejado de compartir el calendario {calendar} con el grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendrio {calendar} con el grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} borró el eventó {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted borró el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó el pendiente {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Usted creo el pendiente {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} borró el pendiente {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usted borró el pendiente {todo} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó el pendiente {todo} de la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Usted actualizó el pendiente {todo} de la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolvió el pendiente {todo} de la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Usted resolvió el pendiente {todo} de la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió el pendiente {todo} de la lista{calendar}",
    "You reopened todo {todo} in list {calendar}" : "Usted reabrió el pendiente {todo} de la lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> de un calendario fue modificado",
    "A calendar <strong>todo</strong> was modified" : "Un <strong>pendiente</strong> de un calendario fue modificado",
    "Contact birthdays" : "Cumpleaños del contacto",
    "Hello %s," : "Hola %s:",
    "Link:" : "Link:",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Contacts" : "Contactos",
    "WebDAV" : "WebDAV",
    "Tentative" : "Tentativo",
    "Save" : "Guardar",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de solicitud: %s"
},
"nplurals=2; plural=(n != 1);");
