OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Ứng dụng khách của bạn không được ủy quyền để kết nối. Vui lòng thông báo cho quản trị viên của ứng dụng khách.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URl chuyển hướng của bạn phải là URL đầy đủ, vd: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Cho phép xác thực tương thích với OAuth2 từ các ứng dụng web khác.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Ứng dụng OAuth2 cho phép các quản trị viên thiết lập dòng chảy công việc xác thực để cũng cho phép xác thực tương thích với OAuth2 từ các ứng dụng web khác.",
    "OAuth 2.0 clients" : "kết nối OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 cho phép các dịch vụ ở ngoài yêu cầu quyền truy cập vào {instanceName}.",
    "Name" : "Tên",
    "Redirection URI" : "Liên kết chuyển tiếp",
    "Client Identifier" : "Mã định danh ứng dụng khách",
    "Add client" : "Thêm kết nối",
    "Add" : "Thêm",
    "Show client secret" : "Hiện bí mật ứng dụng khách",
    "Delete" : "Xóa",
    "Secret" : "Mật khẩu"
},
"nplurals=1; plural=0;");
