OC.L10N.register(
    "files",
    {
    "File could not be found" : "O ficheiro não foi encontrado",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Transferir",
    "Delete" : "Apagar",
    "Tags" : "Etiquetas",
    "Show list view" : "Mostrar visualização em lista",
    "Show grid view" : "Mostrar visualização em grelha",
    "Home" : "Início",
    "Close" : "Fechar",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "This will stop your current uploads." : "Isto irá interromper os seus carregamentos atuais.",
    "Upload cancelled." : "Envio cancelado.",
    "Processing files …" : "A processar ficheiros...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não é possível enviar {filename}, porque este é uma diretoria ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente, está a enviar {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "A pasta de destino \"{dir}\" já não existe",
    "Not enough free space" : "Espaço insuficiente",
    "An unknown error has occurred" : "Ocorreu um erro desconhecido",
    "File could not be uploaded" : "O ficheiro não foi carregado",
    "Uploading …" : "A carregar ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "O carregamento do item não é suportado",
    "Target folder does not exist any more" : "A pasta de destino já não existe",
    "Operation is blocked by access control" : "A operação está bloqueada pelo controlo de acesso",
    "Error when assembling chunks, status code {status}" : "Erro ao agregar partições, código de estado: {status}",
    "Actions" : "Ações",
    "Rename" : "Renomear",
    "Move" : "Mover",
    "Copy" : "Copiar",
    "Choose target folder" : "Escolher pasta de destino",
    "Edit locally" : "Editar localmente",
    "Open" : "Abrir",
    "Delete file" : "Apagar ficheiro",
    "Delete folder" : "Apagar pasta",
    "Disconnect storage" : "Desligue o armazenamento",
    "Leave this share" : "Sair desta partilha",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
    "Files" : "Ficheiros",
    "Details" : "Detalhes",
    "Please select tag(s) to add to the selection" : "Selecione a(s) etiquetas(s) para adicionar à seleção ",
    "Apply tag(s) to selection" : "Aplicar etiqueta(s) à seleção",
    "Select directory \"{dirName}\"" : "Selecionar o diretório \"{dirName}\"",
    "Select file \"{fileName}\"" : "Selecionar o ficheiro \"{fileName}\"",
    "Pending" : "Pendente",
    "Unable to determine date" : "Não é possível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", o destino já existe",
    "Could not copy \"{file}\"" : "Impossível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiado {origin} para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} outros ficheiros para dentro de {destination}",
    "Failed to redirect to client" : "Erro ao redirecionar para o cliente",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
    "Could not fetch file details \"{file}\"" : "Não foi possível obter os detalhes do ficheiro \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado noutras pastas para {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digite mais de dois caracteres para pesquisar noutras pastas",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n ocultos","incluindo %n ocultos","incluindo %n ocultos"],
    "You do not have permission to upload or create files here" : "Não tem permissão para carregar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros","A enviar %n ficheiros"],
    "New" : "Novo",
    "New file/folder menu" : "Novo menu ficheiro/pasta",
    "Select file range" : "Selecionar o intervalo",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "utilizado {used} de {quota}",
    "{used} used" : "{used} utilizado",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido dentro de um nome de um ficheiro.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de ficheiro permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "O armazenamento de {owner} está cheio. Os ficheiros não podem ser enviados ou sincronizados.",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "A pasta de grupo \"{mountPoint}\" está quase cheia ({usedSpacePercent}%).",
    "View in folder" : "Ver na pasta",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Favorited" : "Nos Favoritos",
    "Favorite" : "Favorito",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar hiperligação direta (apenas funciona para os utilizadores que tenham acesso a este ficheiro/pasta)",
    "New folder" : "Nova pasta",
    "Create new folder" : "Criar nova pasta",
    "Upload file" : "Enviar ficheiro",
    "Recent" : "Recentes",
    "Not favorited" : "Não favorito",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Removido dos favoritos",
    "You added {file} to your favorites" : "Adicionou {file} aos favoritos",
    "You removed {file} from your favorites" : "Removeu {file} dos favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Alterações no ficheiro",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Apagado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"utilizador remoto\"",
    "You created {file}" : "Criou {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{user} created an encrypted file in {file}" : "{user} criou um ficheiro encriptado em {file}",
    "{file} was created in a public folder" : "{file} foi criado numa pasta pública",
    "You changed {file}" : "Modificou {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "You deleted {file}" : "Eliminou {file}",
    "{user} deleted {file}" : "{user} eliminou {file}",
    "You restored {file}" : "Restaurou {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Renomeou {oldfile} (oculto) para {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Renomeou {oldfile} (oculto) para {newfile}",
    "You renamed {oldfile} to {newfile}" : "Renomeou {oldfile} para {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um ficheiro foi adicionado ou removido dos seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
    "Upload (max. %s)" : "Envio (máx. %s)",
    "Accept" : "Aceitar",
    "in %s" : "em %s",
    "File name" : "Nome do ficheiro",
    "Folder name" : "Nome da pasta",
    "Name cannot be empty" : "O Nome não pode estar vazio",
    "Select all" : "Selecionar todos",
    "File not found" : "Ficheiro não encontrado",
    "Change" : "Mudar",
    "Transfer" : "Transfere",
    "Unknown error" : "Erro desconhecido",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
    "Go back" : "Voltar",
    "Share" : "Partilhar",
    "Shared by link" : "Partilhado por hiperligação",
    "Shared" : "Partilhados",
    "Show hidden files" : "Mostrar ficheiros ocultos",
    "Additional settings" : "Definições adicionais",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Create" : "Criar",
    "Delete permanently" : "Eliminar permanentemente",
    "Templates" : "Modelos",
    "No favorites yet" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
    "All files" : "Todos os ficheiros",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Upload too large" : "Envio muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt",
    "Storage invalid" : "Armazenamento inválido",
    "You can only favorite a single file or folder at a time" : "Apenas pode definir como favorito um ficheiro ou uma pasta de cada vez",
    "Unlimited" : "Ilimitado",
    "Cancel" : "Cancelar",
    "%s used" : "%s utilizado",
    "%1$s of %2$s used" : "Usado %1$s de %2$s",
    "Deleted files" : "Ficheiros eliminados",
    "Shares" : "Partilhas",
    "Shared with others" : "Partilhado com terceiros",
    "Shared with you" : "Partilhado consigo ",
    "Choose" : "Escolher"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
