OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "Visor de PDF",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Ver documentos PDF directamente no seu Nextcloud.\nAdemáis, esta aplicación tamén pode amosar ficheiros de Adobe Illustrator (.ai).\nDesenvolvido por [pdf.js](https://mozilla.github.io/pdf.js/)",
    "File upload failed." : "Produciuse un fallo ao enviar o ficheiro."
},
"nplurals=2; plural=(n != 1);");
