OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "PDF приказивач",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Гледајте ваше PDF документе директно у Nextcloud. \nКао додатна могућност, ова апликација такође може да прикаже и Adobe Illustrator (.ai) фајлове. \nПокреће [pdf.js](https://mozilla.github.io/pdf.js/)",
    "File upload failed." : "Није успело отпремање фајла."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
