OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "您的客戶端無權連線。請通知您客戶端的管理員。",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "您的重新導向 URL 必須為完整的 URL，例如：https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "允許來自其他網路應用程式的 OAuth2 相容身份驗證。",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 應用程式讓管理員可以設定內建的身份驗證工作流程，以讓其他網路應用程式可以進行相容於 OAuth2 的身份驗證。",
    "OAuth 2.0 clients" : "OAuth 2.0 客戶端",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 讓外部服務請求存取 {instanceName}。",
    "Name" : "名稱",
    "Redirection URI" : "重新導向 URI",
    "Client Identifier" : "客戶端識別",
    "Secret key" : "私鑰",
    "Delete client" : "刪除用戶端",
    "Add client" : "新增客戶端",
    "Add" : "新增",
    "Show client secret" : "顯示客戶端密碼",
    "Delete" : "刪除",
    "Secret" : "密碼"
},
"nplurals=1; plural=0;");
