OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotos",
    "Videos" : "Videos",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Back" : "Atrás",
    "Save" : "Guardar",
    "Shared by" : "Compartido por",
    "Favorite" : "Hacer favorito",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add" : "Agregar",
    "Details" : "Detalles"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
