OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "日历",
    "Calendar \"%s\"" : "日历 “%s”",
    "Deck" : "看板",
    "Deck board \"%s\"" : "看板 “%s”",
    "Files" : "文件",
    "File \"%s\"" : "文件 “%s”",
    "Group Folder" : "群组文件夹",
    "Group Folder \"%s\"" : "群组文件夹 “%s”",
    "Talk conversation" : "通话应用对话",
    "Conversation with %s" : "与 %s 的对话",
    "Talk" : "通话",
    "Talk conversation \"%s\"" : "对话\"%s\"",
    "Related Resources" : "相关资源",
    "Displays resources related to current item in right panel" : "在右侧面板显示与当前项目相关的资源",
    "Displays resources related to current item in right panel." : "在右侧面板显示与当前项目相关的资源。"
},
"nplurals=1; plural=0;");
