OC.L10N.register(
    "photos",
    {
    "Public link" : "Enllaz públicu",
    "Photos" : "Semeyes",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "People" : "Persones",
    "Folders" : "Carpetes",
    "Tags" : "Etiquetes",
    "Places" : "Llugares",
    "Back" : "Atrás",
    "Save" : "Guardar",
    "New album" : "Álbum nuevu",
    "_%n item_::_%n photos and videos_" : ["%n elementu","%n elementos"],
    "Group" : "Grupu",
    "Public link copied!" : "¡Copióse l'enllaz públicu!",
    "This collection does not exist" : "Esta coleición nun esiste",
    "An error occurred" : "Prodúxose un error",
    "View" : "Ver",
    "_%n photo_::_%n photos_" : ["%n semeya","%n semeyes"],
    "This place does not have any photos or videos yet!" : "¡Esti llugar nun tien nenguna semeya nin nengún videu!",
    "Add" : "Amestar",
    "_%n photos_::_%n photos_" : ["%n semeya","%n semeyes"],
    "Details" : "Detalles"
},
"nplurals=2; plural=(n != 1);");
