OC.L10N.register(
    "support",
    {
    "Link:" : "Poveznica:",
    "Password:" : "Zaporka:",
    "Generating system report failed." : "Neuspješno generiranje izvješća o stanju sustava.",
    "Could not create folder \"System information\" to store generated report." : "Nije uspjelo stvaranje mape „Podaci o sustavu” za spremanje generiranog izvješća.",
    "Could not create file \"%s\" to store generated report." : "Nije uspjelo stvaranje datoteke „%s” za spremanje generiranog izvješća.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Dijeljenje datoteke „%s” nije uspjelo. Unatoč tome, možete je pronaći u mapi „Informacije o sustavu“.",
    "Subscription notifications" : "Obavijesti o pretplati",
    "Nextcloud Subscription" : "Nextcloud pretplata",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Vaš poslužitelj nema Nextcloud pretplatu ili je pretplata istekla.",
    "Your Nextcloud server subscription does not cover your number of users." : "Pretplata Nextcloud vašeg poslužitelja ne pokriva traženi broj korisnika.",
    "Your Nextcloud Subscription has expired!" : "Vaša je Nextcloud pretplata istekla!",
    "Your server has no Nextcloud Subscription" : "Vaš poslužitelj nema Nextcloud pretplatu",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Vaš Nextcloudov poslužitelj nema Nextcloud Enterprise pretplatu.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Ako dođe do poteškoća u radu poslužitelja koje onemogućuju rad vašim zaposlenicima, ne morate se oslanjati na pretraživanje mrežnih foruma. Imate izravan pristup našim iskusnim inženjerima!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Sklopili ste ugovor s dobavljačem koji vam isporučuje sve potrebne sigurnosne informacije, načine ublažavanja rizika, zakrpe i ažuriranja.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Ako se želite zadržati na trenutnoj inačici sustava, ne trebate pokretati softver bez sigurnosnih ažuriranja.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Dostupno vam je najbolje stručno znanje za rješavanje problema performansi i skalabilnosti.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Možete pristupiti odgovarajućoj dokumentaciji koja sadrži odgovore na pitanja o usklađenosti s GDPR-om, HIPAA-om i drugim propisima.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Također vam omogućujemo integraciju s Outlookom, paketom Online Office, skalabilnu integriranu komunikaciju putem glasovnih i videopoziva ili razmjene poruka i druge značajke koje su u ograničenom obliku dostupne besplatno te ćemo razviti daljnje integracije i mogućnosti prema vašim potrebama.",
    "A subscription helps you get the most out of Nextcloud!" : "Pretplata vam pomaže da najbolje iskoristite Nextcloud!",
    "Learn more now" : "Saznajte više",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Aplikacija za podršku vaše instance Nextclouda na %1$s poslala je ovu poruku svim administratorima jer imate više od %2$s registriranih korisnika.",
    "Your Nextcloud server Subscription is over limit" : "Vaša Nextcloud pretplata je prekoračena",
    "Dear admin," : "Poštovani administratore,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "vaša Nextcloud pretplata ne pokriva broj aktivnih korisnika na ovom poslužitelju. Obratite se svom upravitelju Nextcloudovog računa kako biste ažurirali svoju pretplatu!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s je vaš upravitelj računa i možete mu se obratiti putem e-pošte %2$s ili telefonom na %3$s.",
    "Thank you," : "Hvala,",
    "Your Nextcloud team" : "Vaš Nextcloudov tim",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Aplikacija za podršku vaše instance Nextclouda na %s poslala je ovu poruku svim administratorima jer broj vaših korisnika prekoračuje broj koji pokriva pretplata.",
    "Your Nextcloud server Subscription is expired" : "Vaša je pretplata za Nextcloud poslužitelj istekla",
    "Your Nextcloud server Subscription is expired!" : "Vaša je pretplata za Nextcloud poslužitelj istekla!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Vaša Nextcloud pretplata je istekla. Obratite se svom upravitelju Nextcloudovog računa kako biste ažurirali svoju pretplatu!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Aplikacija za podršku vaše instance Nextclouda na %s poslala je ovu poruku svim administratorima jer je istekla vaša Nextcloud pretplata.",
    "Support" : "Podrška",
    "Getting support and help for your Nextcloud" : "Traženje podrške i pomoći za Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Aplikacija za podršku daje vam izravan pristup podršci i savjetima, namjenskim kontaktima upravitelja vašeg računa i pregled vaše Enterprise pretplate.",
    "Basic subscription" : "Osnovna pretplata",
    "Standard subscription" : "Standardna pretplata",
    "Premium subscription" : "Premium pretplata",
    "Géant subscription" : "Géant pretplata",
    "Silver partner subscription" : "Silver partner pretplata",
    "Gold partner subscription" : "Gold partner pretplata",
    "Subscription" : "Pretplata",
    "Over subscription limit" : "Prekoračenje ograničenja pretplate",
    "Valid subscription" : "Važeća pretplata",
    "Expired subscription" : "Istekla pretplata",
    "Subscription key:" : "Šifra pretplate:",
    "Expires in: " : "Istječe za: ",
    "_%n year_::_%n years_" : ["%n godina","%n godina","%n godina"],
    "_%n month_::_%n months_" : ["%n mjesec","%n mjeseci","%n mjeseci"],
    "_%n week_::_%n weeks_" : ["%n tjedan","%n tjedna","%n tjedana"],
    "_%n day_::_%n days_" : ["%n dan","%n dana","%n dana"],
    "For an unlimited amount of users" : "Za neograničen broj korisnika",
    "_For %n active users_::_For %n active users_" : ["Za %n aktivnih korisnika","Za %n aktivnih korisnika","Za %n aktivnih korisnika"],
    "_For %n users_::_For %n users_" : ["Za %n korisnika","Za %n korisnika","Za %n korisnika"],
    "_currently at %n user_::_currently at %n users_" : ["trenutno %n korisnik","trenutno %n korisnika","trenutno %n korisnika"],
    "Includes support for %s" : "Uključuje podršku za %s",
    "Includes support for %1$s & %2$s" : "Uključuje podršku za %1$s i %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Uključuje podršku za %1$s, %2$s i %3$s",
    "Extended maintenance life cycle" : "Prošireni ciklus održavanja",
    "Update subscription key" : "Ažuriraj šifru pretplate",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s je voditelj računa. Slobodno nam se obratite ako imate pitanja u vezi s pretplatom.",
    "You can find answers to common question in our portal and also file support requests there." : "Odgovore na česta pitanja možete pronaći na našem portalu i također podnijeti zahtjeve za podrškom.",
    "Access Nextcloud portal" : "Pristupite portalu Nextcloud",
    "System information" : "Podaci o sustavu",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Prikupite podatke o sustavu za slučaj da vam je potrebna podrška. Gumb u nastavku stvara tekstnu datoteku u mapi „Podaci o sustavu” i dijeli je putem javne poveznice zaštićene zaporkom. Poveznica vrijedi 2 tjedna.",
    "Generate system report" : "Generiraj izvješće o stanju sustava",
    "Enterprise subscription recommended" : "Preporučuje se Enterprise pretplata",
    "No active enterprise subscription" : "Nema aktivne Enterprise pretplate",
    "Unsupported" : "Bez podrške",
    "This Nextcloud server has no Enterprise Subscription." : "Ovaj Nextcloudov poslužitelj nema Enterprise pretplatu.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Nextcloudova Enterprise pretplata pomaže vam da najbolje iskoristite Nextcloud, zaštitite svoje podatke i da vaš poslužitelj pouzdano radi u svakom trenutku.",
    "Advantages" : "Pogodnosti",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Pristup tehničkom znanju Nextcloudovih razvojnih programera kroz dokumentaciju i podršku",
    "Access to additional capabilities like Outlook integration, online office and more" : "Pristup dodatnim mogućnostima kao što je integracija s Outlookom, paketom Online Office i još mnogo toga",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Pristup znanjima i mogućnostima skalabilnosti za aplikacije Files i Talk",
    "Optional branding, consulting, architecture advice" : "Mogućnosti brendiranja, savjetovanja, izrade arhitekture",
    "Confidential security notification service, mitigations, patches and advice" : "Povjerljive sigurnosne obavijesti, ublažavanje rizika, zakrpe i savjeti",
    "Compliance certification, advice and documentation" : "Certifikacije, savjeti i dokumentacija za usklađivanje s propisima",
    "Get a quote" : "Zatraži ponudu",
    "More information" : "Više informacija",
    "Subscription benefits" : "Pogodnosti pretplate",
    "Pricing" : "Cijene",
    "Community support" : "Podrška zajednice",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud je besplatni softver koji podržava vrlo aktivna zajednica. Registrirajte se na forumu kako biste postavljali pitanja i razgovarali s drugim članovima.",
    "Nextcloud forum" : "Nextcloudov forum",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud upotrebljava GitHub kao platformu za suradnju. Izvješća o pogreškama možete prijavljivati na ovoj platformi.",
    "Nextcloud at GitHub" : "Nextcloud na GitHubu",
    "Subscription key" : "Šifra pretplate",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Ovdje unesite odgovarajuću šifru ako imate aktivnu pretplatu na Nextcloud.",
    "Learn more about an enterprise subscription." : "Saznajte više o Enterprise pretplati.",
    "Set subscription key" : "Postavi šifru pretplate",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Podaci o pretplati trenutno nisu dostupni. Izvršit će se ponovni pokušaj. Provjerite kasnije.",
    "The subscription key was invalid." : "Šifra pretplate nije valjana.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Nije bilo moguće provjeriti šifru pretplate jer ovaj poslužitelj nema aktivnu internetsku vezu. Obratite se timu za podršku.",
    "The subscription key had an invalid format." : "Šifra pretplate ima nevažeći oblik.",
    "While fetching the subscription information an error happened." : "Došlo je do pogreške pri dohvaćanju podataka o pretplati.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Gumb u nastavku stvara tekstnu datoteku u mapi „Podaci o sustavu” i dijeli je putem javne poveznice zaštićene zaporkom. Poveznica vrijedi 2 tjedna.",
    "News" : "Vijesti",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Kako biste primili ažurne informacije o Nextcloudu, prijavite se na naš bilten i pratite nas na društvenim mrežama.",
    "Like our Facebook page" : "Pratite našu Facebook stranicu",
    "Follow us on Twitter" : "Pratite nas na Twitteru",
    "Check out our blog" : "Pogledajte naš blog",
    "Subscribe to our newsletter" : "Pretplatite se na naše obavijesti"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
