<?php
namespace Aws\IVS\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Interactive Video Service** service.
 */
class IVSException extends AwsException {}
