OC.L10N.register(
    "user_ldap",
    {
    "Failed to delete the server configuration" : "D'Server-Konfiguratioun konnt net geläscht ginn",
    "The configuration is invalid: anonymous bind is not allowed." : "Dës Konfiguratioun ass ongëlteg: eng anonym Bindung ass net erlaabt.",
    "Action does not exist" : "Dës Aktioun gëtt et net",
    "Testing configuration…" : "D'Konfiguratioun gëtt getest...",
    "Configuration incorrect" : "D'Konfiguratioun ass net korrekt",
    "Configuration incomplete" : "D'Konfiguratioun ass net komplett",
    "Configuration OK" : "Konfiguratioun OK",
    "Select groups" : "Wiel Gruppen äus",
    "Saving failed. Please make sure the database is in Operation. Reload before continuing." : "D'Späicheren huet net geklappt. W.e.g. géi sécher dass Datebank an der Operatioun ass. Lued nach emol éiers de weider fiers.",
    "Select attributes" : "Wiel Attributer aus",
    "User not found. Please check your login attributes and username. Effective filter (to copy-and-paste for command line validation): <br/>" : "De Benotzer konnt net fonnt ginn. W.e.g. kuck deng Login Attributer a Benotzernumm no. \n ",
    "_%s group found_::_%s groups found_" : ["%s Grupp fonnt","%s Gruppe fonnt"],
    "_%s user found_::_%s users found_" : ["%s Benotzer fonnt","%s Benotzere fonnt"],
    "Could not find the desired feature" : "Déi gewënschte Funktioun konnt net fonnt ginn",
    "Server" : "Server",
    "Users" : "Benotzer",
    "Groups" : "Gruppen",
    "Test Configuration" : "Konfiguratiounstest",
    "Help" : "Hëllef",
    "Groups meeting these criteria are available in %s:" : "D'Gruppen, déi dës Critèren erfëllen sinn am %s:",
    "Only these object classes:" : "Nëmmen des Klass vun Objeten:",
    "Only from these groups:" : "Nëmme vun dëse Gruppen:",
    "Search groups" : "Sich Gruppen",
    "Available groups" : "Disponibel Gruppen",
    "Selected groups" : "Ausgewielte Gruppen",
    "Test Loginname" : "Test Benotzernumm",
    "Verify settings" : "Astellungen iwwerpréiwen",
    "1. Server" : "1. Server",
    "%s. Server:" : "%s. Server",
    "Delete the current configuration" : "Läsch déi aktuell Konfiguratioun",
    "Host" : "Host",
    "Port" : "Port",
    "User DN" : "Benotzer DN",
    "Password" : "Passwuert",
    "Saving" : "Speicheren...",
    "Back" : "Zeréck",
    "Continue" : "Weider",
    "Advanced" : "Erweidert",
    "Connection Settings" : "D'Astellunge vun der Verbindung",
    "Configuration Active" : "D'Konfiguratioun ass aktiv",
    "When unchecked, this configuration will be skipped." : "Ouni Iwwerpréiwung wäert dës Konfiguratioun iwwergaange ginn.",
    "Directory Settings" : "Dossier's Astellungen",
    "in bytes" : "A Bytes",
    "Email Field" : "Email Feld",
    "Internal Username" : "Interne Benotzernumm",
    "Internal Username Attribute:" : "Interne Benotzernumm Attribut:"
},
"nplurals=2; plural=(n != 1);");
