OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "taastatud",
    "Deleted files" : "Kustutatud failid",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Kustutatud failid ja kaustad prügikastis (võivad ekspordi käigus aeguda, kui salvestusruum on otsakorral)",
    "This application enables users to restore files that were deleted from the system." : "See rakendus võimaldab kasutajatel kustutatud faile taastada.",
    "This application enables users to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the users file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent a user from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "See rakendus võimaldab kasutajatel kustutatud faile taastada. Veebiliideses kuvatakse kustutatud failide loendit koos võimalusega need kas kasutaja failide hulka taastada või jäädavalt kustutada. Faili taastamine taastab ka selle versioonid, kui versioonide rakendus on lubatud. Kui fail kustutatakse jaoskaustast, saab seda samal moel taastada, ehkki see pole siis enam jagatud. Vaikimisi on failid prügikastus kuni 30 päeva.\nEt vältida kasutaja salvestusruumi otsasaamist, ei kasuta rakendus rohkem kui 50% saadaolevast salvestusruumist. Kui kustutatud failide maht ületab seda limiiti, kustutab rakendus järjest vanemaid faile, kuni maht jääb alla limiidi. Rohkem infot rakenduse dokumentatsioonis.",
    "Restore" : "Taasta",
    "List of files that have been deleted." : "Kustutatud failide loend.",
    "No deleted files" : "Kustutatud faile pole",
    "Deleted" : "Kustutatud",
    "You will be able to recover deleted files from here" : "Siit saad kustutatud faile taastada",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Name" : "Nimi",
    "Actions" : "Tegevused",
    "Delete permanently" : "Kustuta jäädavalt",
    "Error while restoring file from trash bin" : "Faili prügikastist taastamine ebaõnnestus",
    "Error while removing file from trash bin" : "Faili prügikastist eemaldamine ebaõnnestus",
    "Error while restoring files from trash bin" : "Failide prügikastist taastamine ebaõnnestus",
    "Error while emptying trash bin" : "Prügikasti tühjendamine ebaõnnestus",
    "Error while removing files from trash bin" : "Failide prügikastist eemaldamine ebaõnnestus",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kataloog pole saadaval, palun kontrolli logifaile või võta ühendust administraatoriga",
    "Delete" : "Kustuta"
},
"nplurals=2; plural=(n != 1);");
