<?php
namespace Aws\BillingConductor\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWSBillingConductor** service.
 */
class BillingConductorException extends AwsException {}
