OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "Պատճենված է․",
    "Not supported!" : "Չի՛ սպասարկվում։",
    "Press ⌘-C to copy." : "Սեղմել ⌘-C պատճենելու համար։",
    "Press Ctrl-C to copy." : "Սեղմել  Ctrl-C պատճենելու համար։",
    "Size:" : "Չափս.",
    "Type:" : "Տիպ.",
    "Copy" : "պատճենահանել"
},
"nplurals=2; plural=(n != 1);");
