<?php
namespace Aws\Keyspaces\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Keyspaces** service.
 */
class KeyspacesException extends AwsException {}
