<?php
namespace Aws\IoTFleetWise\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS IoT FleetWise** service.
 */
class IoTFleetWiseException extends AwsException {}
