OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Последни състояния",
    "No recent status changes" : "Няма скорошни промени в състоянието",
    "In a meeting" : "В среща",
    "Commuting" : "Работно пътуване",
    "Out sick" : "Болничен",
    "Vacationing" : "Отпуск",
    "Working remotely" : "Работа от разстояние",
    "In a call" : "В обаждане",
    "User status" : "Потребителско състояние",
    "Clear status after" : "Изчистване на състоянието след",
    "What is your status?" : "Какъв е вашият статус?",
    "Previously set" : "Предишно зададени",
    "Reset status" : "Възстановяване на състоянието",
    "Set status" : "Задаване на състояние",
    "Online status" : "Състояние на линия",
    "Status message" : "Съобщение за състояние",
    "Your status was set automatically" : "Състоянието ви беше зададено автоматично",
    "Clear status message" : "Изчистване на съобщението за състояние",
    "Set status message" : "Задаване на съобщение за състояние",
    "Reset status to \"{icon} {message}\"" : "Възстановяване на състоянието на „{icon} {message}“",
    "Reset status to \"{message}\"" : "Възстановяване на състоянието на „{message}“",
    "Reset status to \"{icon}\"" : "Възстановяване на състоянието на „{icon}“",
    "There was an error saving the status" : "Възникна грешка при запазване на състоянието",
    "There was an error clearing the status" : "Възникна грешка при изчистване на състоянието",
    "There was an error reverting the status" : "Имаше грешка при връщане на състоянието",
    "Don't clear" : "Да не се изчиства",
    "Today" : "Днес",
    "This week" : "Тази седмица",
    "Online" : "На линия",
    "Away" : "Отсъстващ",
    "Do not disturb" : "Не безпокойте",
    "Invisible" : "Невидим",
    "Offline" : "Офлайн",
    "There was an error saving the new status" : "Възникна грешка при запазване на новото състояние",
    "30 minutes" : "30 минути",
    "1 hour" : "1 час",
    "4 hours" : "4 часа",
    "Mute all notifications" : "Заглушаване на всички известия",
    "Appear offline" : "Показване като офлайн",
    "View profile" : "Преглед на профил",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n != 1);");
