OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentlig lenke",
    "Photos" : "Bilder",
    "Your memories under your control" : "Dine minner under din kontroll",
    "All media" : "Alle mediefiler",
    "Videos" : "Filmer",
    "Albums" : "Album",
    "Collaborative albums" : "Samarbeidsalbum",
    "People" : "Mennesker",
    "Folders" : "Mapper",
    "Favorites" : "Favoritter",
    "On this day" : "På denne dagen",
    "Shared with you" : "Delt med deg",
    "Tags" : "Merkelapper",
    "Places" : "Steder",
    "Map" : "Kart",
    "Photos settings" : "Innstillinger for bilder",
    "Mark selection as favorite" : "Merk utvalget som favoritt",
    "Add selection to favorites" : "Legg til utvalg i favoritter",
    "Remove selection from favorites" : "Fjern utvalg fra favoritter",
    "Name of the album" : "Navn på albumet",
    "Location of the album" : "Plassering av albumet",
    "Back" : "Tilbake",
    "Add collaborators" : "Legg til samarbeidspartnere",
    "Save" : "Lagre",
    "Create album" : "Lag album",
    "Add to Album" : "Legg til album",
    "Add selection to album {albumName}" : "Legg til utvalg i albumet {albumName}",
    "Shared by" : "Delt av",
    "Create a new album." : "Opprett et nytt album.",
    "Create new album" : "Lag nytt album",
    "New album" : "Nytt album",
    "_%n item_::_%n photos and videos_" : ["%n element","%n bilder og videoer"],
    "Add people or groups who can edit your album" : "Legg til personer eller grupper som kan redigere albumet ditt",
    "Search people or groups" : "Søk etter personer eller grupper",
    "No recommendations. Start typing." : "Ingen anbefalinger. Start å skrive.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "Fjern {collaboratorLabel} fra samarbeidspartnerlisten",
    "Copy the public link" : "Kopier den offentlige lenken",
    "Public link copied!" : "Offentlig lenke er kopiert!",
    "Copy public link" : "Kopier offentlig lenke",
    "Delete the public link" : "Slett den offentlige lenken",
    "Share via public link" : "Del via offentlig lenke",
    "Failed to fetch collaborators list." : "Kunne ikke hente listen over samarbeidspartnere.",
    "Failed to update album." : "Kunne ikke oppdatere albumet.",
    "This collection does not exist" : "Denne samlingen eksisterer ikke",
    "An error occurred" : "En feil oppsto",
    "Select image {imageName}" : "Velg bilde {imageName}",
    "The file is in the favorites" : "Filen er i favorittene",
    "Open the full size \"{name}\" image" : "Åpne full størrelse av bildet \"{name}\"",
    "There are no photos or videos yet!" : "Det er ingen bilder eller videoer ennå!",
    "Add to {destination}" : "Legg til i {destination}",
    "Open the \"{name}\" sub-directory" : "Åpne undermappen \"{name}\"",
    "Back to {folder}" : "Tilbake til {folder}",
    "Share this folder" : "Del denne mappen",
    "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
    "Enable squared photos view" : "Aktiver visning med kvadratiske bilder",
    "Default Photos upload and Albums location" : "Standard bildeopplasting og albumplassering",
    "Select the default location for your media" : "Velg standardplassering for mediefilene dine",
    "Invalid location selected" : "Invalid location selected",
    "View" : "Vis",
    "Photos directory" : "Bildemappe",
    "_%n photo_::_%n photos_" : ["%n bilde","%n bilder"],
    "Manage collaborators for this album" : "Administrer samarbeidspartnere for dette albumet",
    "Open actions menu" : "Åpne handlingsmenyen",
    "Edit album details" : "Rediger albumdetaljer",
    "Download all files in album" : "Last ned alle filene i albumet",
    "Delete album" : "Slett album",
    "Download selected files" : "Last ned valgte filer",
    "Remove selection from album" : "Fjern utvalg fra album",
    "This album does not have any photos or videos yet!" : "Dette albumet har ingen bilder eller videoer ennå!",
    "Add photos to this album" : "Legg til bilder i dette albumet",
    "Manage collaborators" : "Administrer samarbeidspartnere",
    "Save collaborators for this album." : "Lagre samarbeidspartnere for dette albumet.",
    "Cover photo for album {albumName}" : "Forsidebilde for albumet {albumName}",
    "There is no album yet!" : "Det er ikke noe album ennå!",
    "This person could not be found" : "Denne personen ble ikke funnet",
    "Rename person" : "Gi nytt navn til person",
    "Merge with different person" : "Slå sammen med en annen person",
    "Download selected photos" : "Last ned valgte bilder",
    "Favorite" : "Favoritt",
    "Remove from favorites" : "Fjern fra favoritter",
    "Remove person" : "Fjern person",
    "Name of this person" : "Navnet på denne personen",
    "Save." : "Lagre.",
    "Merge person" : "Slå sammen person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Flytt bildet til en annen person","Flytt bilder til en annen person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fjern bildet fra personen","Fjern bilder fra personen"],
    "This might take some time depending on the size of your photo library." : "Dette kan ta litt tid avhengig av størrelsen på bildebiblioteket ditt.",
    "Recognized people will show up here" : "Anerkjente personer vil dukke opp her",
    "This folder does not exist" : "Denne mappen finnes ikke",
    "Loading folders …" : "Laster inn mapper…",
    "No photos in here" : "Ingen bilder her",
    "Cover photo for shared album {albumName}." : "Forsidebilde for delt album {albumName}.",
    "Back to tags overview" : "Tilbake til merkelappoversikt",
    "No photos with this tag yet" : "Ingen bilder med denne merkelappen ennå",
    "No tags yet" : "Ingen etiketter enda",
    "Photos with tags will show up here" : "Bilder med etiketter vises her",
    "Popular tags" : "Populære merkelapper",
    "Add" : "Legg til",
    "Add to album" : "Legg til i album",
    "Delete selection" : "Slett utvalg",
    "No photos or videos in here" : "Ingen bilder eller videoer her",
    "_%n photos_::_%n photos_" : ["%n bilder","%n bilder"],
    "Failed to fetch faces list." : "Kunne ikke hente ansiktslisten.",
    "All your media" : "Alle mediefilene dine",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Delte album",
    "Shared album {title}" : "Delt album {title}",
    "Public album {title}" : "Offentlig album {title}",
    "Tagged photos" : "Bilder med merkelapper",
    "Tagged photo {title}" : "Merket bilde {title}",
    "{title}'s face" : "{title} sitt ansikt",
    "Details" : "Detaljer",
    "Failed to rename {oldName} to {faceName}." : "Kunne ikke endre navn på {oldName} til {faceName}.",
    "Failed to delete {faceName}." : "Kunne ikke slette {faceName}.",
    "Failed to delete {fileId}." : "Kunne ikke slette {fileId}.",
    "Failed to delete {fileName}." : "Kunne ikke slette {fileName}.",
    "Failed to set favorite state for {fileId}." : "Kunne ikke angi favorittstatus for {fileId}.",
    "Failed to set favorite state for {fileName}." : "Kunne ikke angi favorittstatus for {fileName}.",
    "Locations" : "Steder",
    "Go back to the previous view." : "Gå tilbake til forrige visning.",
    "Go to the add collaborators view." : "Gå til visningen Legg til samarbeidspartnere.",
    "Create the album." : "Lag albumet.",
    "Back to the new album form." : "Tilbake til albumskjemaet.",
    "_Share with %n user_::_Share with %n users_" : ["Del med %n bruker","Del med %n brukere"],
    "Search for collaborators" : "Søk etter samarbeidspartnere",
    "Add {collaboratorLabel} to the collaborators list" : "Legg til {collaboratorLabel} i samarbeidspartnerlisten",
    "No collaborators available" : "Ingen samarbeidspartnere tilgjengelig",
    "Failed to fetch album." : "Kunne ikke hente albumet.",
    "Add photos to the album" : "Legg til bilder i albumet",
    "Failed to fetch albums list." : "Kunne ikke hente albumlisten.",
    "Shared albums" : "Delte album",
    "Create a new album" : "Opprett et nytt album",
    "Add selection to an album" : "Legg til utvalg i et album",
    "Failed to create {albumName}." : "Kunne ikke opprette {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Kunne ikke endre navn på {currentAlbumName} til {newAlbumName}."
},
"nplurals=2; plural=(n != 1);");
