<?php
namespace Aws\CodeStar\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS CodeStar** service.
 */
class CodeStarException extends AwsException {}
